/* AppWindow.c generated by valac 0.40.4, the Vala compiler
 * generated from AppWindow.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <time.h>
#include <gdk/gdk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <cairo.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gee.h>


#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;
typedef struct _PageWindowPrivate PageWindowPrivate;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;
typedef struct _FullscreenWindowPrivate FullscreenWindowPrivate;
enum  {
	FULLSCREEN_WINDOW_0_PROPERTY,
	FULLSCREEN_WINDOW_NUM_PROPERTIES
};
static GParamSpec* fullscreen_window_properties[FULLSCREEN_WINDOW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_SINGLE_PHOTO_PAGE (single_photo_page_get_type ())
#define SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage))
#define SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))
#define IS_SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SINGLE_PHOTO_PAGE))
#define IS_SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SINGLE_PHOTO_PAGE))
#define SINGLE_PHOTO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))

typedef struct _SinglePhotoPage SinglePhotoPage;
typedef struct _SinglePhotoPageClass SinglePhotoPageClass;

#define TYPE_SLIDESHOW_PAGE (slideshow_page_get_type ())
#define SLIDESHOW_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SLIDESHOW_PAGE, SlideshowPage))
#define SLIDESHOW_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SLIDESHOW_PAGE, SlideshowPageClass))
#define IS_SLIDESHOW_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SLIDESHOW_PAGE))
#define IS_SLIDESHOW_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SLIDESHOW_PAGE))
#define SLIDESHOW_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SLIDESHOW_PAGE, SlideshowPageClass))

typedef struct _SlideshowPage SlideshowPage;
typedef struct _SlideshowPageClass SlideshowPageClass;
enum  {
	PAGE_WINDOW_0_PROPERTY,
	PAGE_WINDOW_NUM_PROPERTIES
};
static GParamSpec* page_window_properties[PAGE_WINDOW_NUM_PROPERTIES];

#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))
typedef struct _AppWindowPrivate AppWindowPrivate;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;
enum  {
	APP_WINDOW_0_PROPERTY,
	APP_WINDOW_NUM_PROPERTIES
};
static GParamSpec* app_window_properties[APP_WINDOW_NUM_PROPERTIES];

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;

#define TYPE_DIRECT_WINDOW (direct_window_get_type ())
#define DIRECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DIRECT_WINDOW, DirectWindow))
#define DIRECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DIRECT_WINDOW, DirectWindowClass))
#define IS_DIRECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DIRECT_WINDOW))
#define IS_DIRECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DIRECT_WINDOW))
#define DIRECT_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DIRECT_WINDOW, DirectWindowClass))

typedef struct _DirectWindow DirectWindow;
typedef struct _DirectWindowClass DirectWindowClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define TYPE_COMMAND_DESCRIPTION (command_description_get_type ())
#define COMMAND_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_DESCRIPTION, CommandDescription))
#define IS_COMMAND_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_DESCRIPTION))
#define COMMAND_DESCRIPTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_COMMAND_DESCRIPTION, CommandDescriptionIface))

typedef struct _CommandDescription CommandDescription;
typedef struct _CommandDescriptionIface CommandDescriptionIface;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PageWindow {
	GtkApplicationWindow parent_instance;
	PageWindowPrivate * priv;
};

struct _PageWindowClass {
	GtkApplicationWindowClass parent_class;
	void (*switched_pages) (PageWindow* self, Page* old_page, Page* new_page);
	void (*set_current_page) (PageWindow* self, Page* page);
	void (*clear_current_page) (PageWindow* self);
};

struct _FullscreenWindow {
	PageWindow parent_instance;
	FullscreenWindowPrivate * priv;
};

struct _FullscreenWindowClass {
	PageWindowClass parent_class;
};

struct _FullscreenWindowPrivate {
	GtkOverlay* overlay;
	GtkToolbar* toolbar;
	GtkToolButton* close_button;
	GtkToggleToolButton* pin_button;
	gboolean is_toolbar_shown;
	gboolean waiting_for_invoke;
	time_t left_toolbar_time;
	gboolean switched_to;
	gboolean is_toolbar_dismissal_enabled;
};

struct _PageWindowPrivate {
	Page* current_page;
	gint busy_counter;
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _AppWindow {
	PageWindow parent_instance;
	AppWindowPrivate * priv;
	gboolean maximized;
	Dimensions dimensions;
	gint pos_x;
	gint pos_y;
};

struct _AppWindowClass {
	PageWindowClass parent_class;
	void (*on_fullscreen) (AppWindow* self);
	gchar* (*get_app_role) (AppWindow* self);
	void (*on_quit) (AppWindow* self);
	void (*add_actions) (AppWindow* self);
	void (*update_common_action_availability) (AppWindow* self, Page* old_page, Page* new_page);
	void (*update_common_actions) (AppWindow* self, Page* page, gint selected_count, gint count);
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()
struct _CommandDescriptionIface {
	GTypeInterface parent_iface;
	gchar* (*get_name) (CommandDescription* self);
	gchar* (*get_explanation) (CommandDescription* self);
};


static gpointer fullscreen_window_parent_class = NULL;
static gpointer page_window_parent_class = NULL;
static gpointer app_window_parent_class = NULL;
extern AppWindow* app_window_instance;
AppWindow* app_window_instance = NULL;
static FullscreenWindow* app_window_fullscreen_window;
static FullscreenWindow* app_window_fullscreen_window = NULL;
static CommandManager* app_window_command_manager;
static CommandManager* app_window_command_manager = NULL;

GType page_window_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType fullscreen_window_get_type (void) G_GNUC_CONST;
#define FULLSCREEN_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_FULLSCREEN_WINDOW, FullscreenWindowPrivate))
#define FULLSCREEN_WINDOW_TOOLBAR_INVOCATION_MSEC 250
#define FULLSCREEN_WINDOW_TOOLBAR_DISMISSAL_SEC 2
#define FULLSCREEN_WINDOW_TOOLBAR_CHECK_DISMISSAL_MSEC 500
static void fullscreen_window_on_close (FullscreenWindow* self);
static void _fullscreen_window_on_close_gsimple_action_activate_callback (GSimpleAction* action,
                                                                   GVariant* parameter,
                                                                   gpointer self);
FullscreenWindow* fullscreen_window_new (Page* page);
FullscreenWindow* fullscreen_window_construct (GType object_type,
                                               Page* page);
PageWindow* page_window_construct (GType object_type);
void page_window_set_current_page (PageWindow* self,
                                   Page* page);
void application_set_accels_for_action (const gchar* action,
                                        gchar** accel,
                                        int accel_length1);
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
static void fullscreen_window_get_monitor_geometry (FullscreenWindow* self,
                                             GdkRectangle* result);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gboolean configuration_facade_get_pin_toolbar_state (ConfigurationFacade* self);
void fullscreen_window_update_toolbar_dismissal (FullscreenWindow* self);
static void _fullscreen_window_update_toolbar_dismissal_gtk_tool_button_clicked (GtkToolButton* _sender,
                                                                          gpointer self);
GtkToolbar* page_get_toolbar (Page* self);
#define RESOURCES_TRANSIENT_WINDOW_OPACITY 0.90
GType single_photo_page_get_type (void) G_GNUC_CONST;
GType slideshow_page_get_type (void) G_GNUC_CONST;
static void fullscreen_window_hide_toolbar (FullscreenWindow* self);
static void _fullscreen_window_hide_toolbar_slideshow_page_hide_toolbar (SlideshowPage* _sender,
                                                                  gpointer self);
void page_set_cursor_hide_time (Page* self,
                                gint hide_time);
void page_start_cursor_hiding (Page* self);
gboolean configuration_facade_get_display_toolbar (ConfigurationFacade* self);
static void fullscreen_window_invoke_toolbar (FullscreenWindow* self);
void fullscreen_window_disable_toolbar_dismissal (FullscreenWindow* self);
static gboolean fullscreen_window_real_configure_event (GtkWidget* base,
                                                 GdkEventConfigure* event);
Page* page_window_get_current_page (PageWindow* self);
void page_switched_to (Page* self);
static gboolean fullscreen_window_real_key_press_event (GtkWidget* base,
                                                 GdkEventKey* event);
void configuration_facade_set_pin_toolbar_state (ConfigurationFacade* self,
                                                 gboolean state);
void app_window_end_fullscreen (AppWindow* self);
void fullscreen_window_close (FullscreenWindow* self);
static void fullscreen_window_real_destroy (GtkWidget* base);
void page_window_clear_current_page (PageWindow* self);
void page_stop_cursor_hiding (Page* self);
void page_switching_from (Page* self);
static gboolean fullscreen_window_real_delete_event (GtkWidget* base,
                                              GdkEventAny* event);
static gboolean fullscreen_window_real_motion_notify_event (GtkWidget* base,
                                                     GdkEventMotion* event);
static gboolean fullscreen_window_is_pointer_in_toolbar (FullscreenWindow* self);
static gboolean fullscreen_window_on_check_toolbar_invocation (FullscreenWindow* self);
static gboolean _fullscreen_window_on_check_toolbar_invocation_gsource_func (gpointer self);
static gboolean fullscreen_window_on_check_toolbar_dismissal (FullscreenWindow* self);
static gboolean _fullscreen_window_on_check_toolbar_dismissal_gsource_func (gpointer self);
static void fullscreen_window_finalize (GObject * obj);
#define PAGE_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PAGE_WINDOW, PageWindowPrivate))
void page_window_switched_pages (PageWindow* self,
                                 Page* old_page,
                                 Page* new_page);
static void page_window_real_switched_pages (PageWindow* self,
                                      Page* old_page,
                                      Page* new_page);
gpointer application_ref (gpointer instance);
void application_unref (gpointer instance);
GParamSpec* param_spec_application (const gchar* name,
                                    const gchar* nick,
                                    const gchar* blurb,
                                    GType object_type,
                                    GParamFlags flags);
void value_set_application (GValue* value,
                            gpointer v_object);
void value_take_application (GValue* value,
                             gpointer v_object);
gpointer value_get_application (const GValue* value);
GType application_get_type (void) G_GNUC_CONST;
Application* application_get_instance (void);
GtkApplication* application_get_system_app (Application* self);
static void page_window_real_set_current_page (PageWindow* self,
                                        Page* page);
void page_clear_container (Page* self);
void page_set_container (Page* self,
                         GtkWindow* container);
static void page_window_real_clear_current_page (PageWindow* self);
static gboolean page_window_real_key_press_event (GtkWidget* base,
                                           GdkEventKey* event);
gboolean page_notify_app_key_pressed (Page* self,
                                      GdkEventKey* event);
static gboolean page_window_real_key_release_event (GtkWidget* base,
                                             GdkEventKey* event);
gboolean page_notify_app_key_released (Page* self,
                                       GdkEventKey* event);
static gboolean page_window_real_focus_in_event (GtkWidget* base,
                                          GdkEventFocus* event);
gboolean page_notify_app_focus_in (Page* self,
                                   GdkEventFocus* event);
static gboolean page_window_real_focus_out_event (GtkWidget* base,
                                           GdkEventFocus* event);
gboolean page_notify_app_focus_out (Page* self,
                                    GdkEventFocus* event);
static gboolean page_window_real_configure_event (GtkWidget* base,
                                           GdkEventConfigure* event);
gboolean page_notify_configure_event (Page* self,
                                      GdkEventConfigure* event);
void page_window_set_busy_cursor (PageWindow* self);
void spin_event_loop (void);
void page_window_set_normal_cursor (PageWindow* self);
static void page_window_finalize (GObject * obj);
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_command_manager (GValue* value,
                                gpointer v_object);
void value_take_command_manager (GValue* value,
                                 gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
#define APP_WINDOW_DND_ICON_SCALE 128
void app_window_on_about (AppWindow* self);
static void _app_window_on_about_gsimple_action_activate_callback (GSimpleAction* action,
                                                            GVariant* parameter,
                                                            gpointer self);
void app_window_on_quit (AppWindow* self);
static void _app_window_on_quit_gsimple_action_activate_callback (GSimpleAction* action,
                                                           GVariant* parameter,
                                                           gpointer self);
void app_window_on_fullscreen (AppWindow* self);
static void _app_window_on_fullscreen_gsimple_action_activate_callback (GSimpleAction* action,
                                                                 GVariant* parameter,
                                                                 gpointer self);
static void app_window_on_help_contents (AppWindow* self);
static void _app_window_on_help_contents_gsimple_action_activate_callback (GSimpleAction* action,
                                                                    GVariant* parameter,
                                                                    gpointer self);
static void app_window_on_help_faq (AppWindow* self);
static void _app_window_on_help_faq_gsimple_action_activate_callback (GSimpleAction* action,
                                                               GVariant* parameter,
                                                               gpointer self);
static void app_window_on_help_report_problem (AppWindow* self);
static void _app_window_on_help_report_problem_gsimple_action_activate_callback (GSimpleAction* action,
                                                                          GVariant* parameter,
                                                                          gpointer self);
static void app_window_on_undo (AppWindow* self);
static void _app_window_on_undo_gsimple_action_activate_callback (GSimpleAction* action,
                                                           GVariant* parameter,
                                                           gpointer self);
static void app_window_on_redo (AppWindow* self);
static void _app_window_on_redo_gsimple_action_activate_callback (GSimpleAction* action,
                                                           GVariant* parameter,
                                                           gpointer self);
void app_window_on_jump_to_file (AppWindow* self);
static void _app_window_on_jump_to_file_gsimple_action_activate_callback (GSimpleAction* action,
                                                                   GVariant* parameter,
                                                                   gpointer self);
static void app_window_on_select_all (AppWindow* self);
static void _app_window_on_select_all_gsimple_action_activate_callback (GSimpleAction* action,
                                                                 GVariant* parameter,
                                                                 gpointer self);
static void app_window_on_select_none (AppWindow* self);
static void _app_window_on_select_none_gsimple_action_activate_callback (GSimpleAction* action,
                                                                  GVariant* parameter,
                                                                  gpointer self);
AppWindow* app_window_construct (GType object_type);
#define RESOURCES_APP_TITLE "Shotwell"
GType library_window_get_type (void) G_GNUC_CONST;
void configuration_facade_get_library_window_state (ConfigurationFacade* self,
                                                    gboolean* maximize,
                                                    Dimensions* dimensions);
GType direct_window_get_type (void) G_GNUC_CONST;
void configuration_facade_get_direct_window_state (ConfigurationFacade* self,
                                                   gboolean* maximize,
                                                   Dimensions* dimensions);
#define COMMAND_MANAGER_DEFAULT_DEPTH 20
CommandManager* command_manager_new (gint depth);
CommandManager* command_manager_construct (GType object_type,
                                           gint depth);
static void app_window_on_command_manager_altered (AppWindow* self);
static void _app_window_on_command_manager_altered_command_manager_altered (CommandManager* _sender,
                                                                     gboolean can_undo,
                                                                     gboolean can_redo,
                                                                     gpointer self);
void app_window_add_actions (AppWindow* self);
#define RESOURCES_CUSTOM_CSS "LibraryWindow .pane-separator {\n" \
"               background-color: @borders;\n" \
"            }\n" \
"            SearchFilterToolbar {\n" \
"               border-width: 0 0 1px 0;\n" \
"               border-style: solid;\n" \
"               border-color: @borders;\n" \
"            }"
static void app_window_real_on_fullscreen (AppWindow* self);
gboolean app_window_has_instance (void);
FullscreenWindow* app_window_get_fullscreen (void);
GtkBuilder* app_window_create_builder (const gchar* glade_filename,
                                       void* user);
gchar* resources_get_ui (const gchar* filename);
void app_window_error_message (const gchar* message,
                               GtkWindow* parent);
void app_window_error_message_with_title (const gchar* title,
                                          const gchar* message,
                                          GtkWindow* parent,
                                          gboolean should_escape);
gchar* build_alert_body_text (const gchar* primary_text,
                              const gchar* secondary_text,
                              gboolean should_escape);
gboolean app_window_negate_affirm_question (const gchar* message,
                                            const gchar* negative,
                                            const gchar* affirmative,
                                            const gchar* title,
                                            GtkWindow* parent);
GtkResponseType app_window_negate_affirm_cancel_question (const gchar* message,
                                                          const gchar* negative,
                                                          const gchar* affirmative,
                                                          const gchar* title,
                                                          GtkWindow* parent);
GtkResponseType app_window_affirm_cancel_question (const gchar* message,
                                                   const gchar* affirmative,
                                                   const gchar* title,
                                                   GtkWindow* parent);
GtkResponseType app_window_negate_affirm_all_cancel_question (const gchar* message,
                                                              const gchar* negative,
                                                              const gchar* affirmative,
                                                              const gchar* affirmative_all,
                                                              const gchar* title,
                                                              GtkWindow* parent);
GQuark database_error_quark (void);
void app_window_database_error (GError* err);
void app_window_panic (const gchar* msg);
void application_panic (Application* self);
gchar* app_window_get_app_role (AppWindow* self);
static gchar* app_window_real_get_app_role (AppWindow* self);
#define RESOURCES_APP_VERSION _VERSION
#define RESOURCES_COPYRIGHT _ ("Copyright 2016 Software Freedom Conservancy Inc.")
#define RESOURCES_HOME_URL "https://wiki.gnome.org/Apps/Shotwell"
#define RESOURCES_LICENSE "\n" \
"Shotwell is free software; you can redistribute it and/or modify it un" \
"der the \n" \
"terms of the GNU Lesser General Public License as published by the Fre" \
"e \n" \
"Software Foundation; either version 2.1 of the License, or (at your op" \
"tion) \n" \
"any later version.\n" \
"\n" \
"Shotwell is distributed in the hope that it will be useful, but WITHOU" \
"T \n" \
"ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or " \
"FITNESS\n" \
"FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License f" \
"or \n" \
"more details.\n" \
"\n" \
"You should have received a copy of the GNU Lesser General Public Licen" \
"se \n" \
"along with Shotwell; if not, write to the Free Software Foundation, In" \
"c., \n" \
"51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA\n"
GdkPixbuf* resources_get_icon (const gchar* name,
                               gint scale);
#define RESOURCES_ICON_ABOUT_LOGO "about-braunschweig.jpg"
void resources_launch_help (GdkScreen* screen,
                            const gchar* anchor,
                            GError** error);
void app_window_show_uri (AppWindow* self,
                          const gchar* url,
                          GError** error);
#define RESOURCES_BUG_DB_URL "https://wiki.gnome.org/Apps/Shotwell/ReportingABug"
#define RESOURCES_FAQ_URL "https://wiki.gnome.org/Apps/Shotwell/FAQ"
static void app_window_real_on_quit (AppWindow* self);
void application_exit (Application* self);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_data_collection (GValue* value,
                                gpointer v_object);
void value_take_data_collection (GValue* value,
                                 gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType view_collection_get_type (void) G_GNUC_CONST;
ViewCollection* page_get_view (Page* self);
gint view_collection_get_selected_count (ViewCollection* self);
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType data_view_get_type (void) G_GNUC_CONST;
DataView* view_collection_get_selected_at (ViewCollection* self,
                                           gint index);
DataSource* data_view_get_source (DataView* self);
void app_window_show_file_uri (AppWindow* self,
                               GFile* file,
                               GError** error);
GFile* media_source_get_master_file (MediaSource* self);
gchar* resources_jump_to_file_failed (GError* err);
static void app_window_real_destroy (GtkWidget* base);
gchar* get_nautilus_install_location (void);
void show_file_in_nautilus (const gchar* filename,
                            GError** error);
void sys_show_uri (GdkScreen* screen,
                   const gchar* uri,
                   GError** error);
static void app_window_real_add_actions (AppWindow* self);
void app_window_go_fullscreen (AppWindow* self,
                               Page* page);
void page_switching_to_fullscreen (Page* self,
                                   FullscreenWindow* fsw);
void page_returning_from_fullscreen (Page* self,
                                     FullscreenWindow* fsw);
GAction* app_window_get_common_action (AppWindow* self,
                                       const gchar* name);
void app_window_set_common_action_sensitive (AppWindow* self,
                                             const gchar* name,
                                             gboolean sensitive);
void app_window_set_common_action_important (AppWindow* self,
                                             const gchar* name,
                                             gboolean important);
void app_window_set_common_action_visible (AppWindow* self,
                                           const gchar* name,
                                           gboolean visible);
static void app_window_real_switched_pages (PageWindow* base,
                                     Page* old_page,
                                     Page* new_page);
void app_window_update_common_action_availability (AppWindow* self,
                                                   Page* old_page,
                                                   Page* new_page);
static void app_window_on_update_common_actions (AppWindow* self);
static void _app_window_on_update_common_actions_data_collection_contents_altered (DataCollection* _sender,
                                                                            GeeIterable* added,
                                                                            GeeIterable* removed,
                                                                            gpointer self);
static void _app_window_on_update_common_actions_view_collection_selection_group_altered (ViewCollection* _sender,
                                                                                   gpointer self);
static void _app_window_on_update_common_actions_view_collection_items_state_changed (ViewCollection* _sender,
                                                                               GeeIterable* changed,
                                                                               gpointer self);
void app_window_update_common_actions (AppWindow* self,
                                       Page* page,
                                       gint selected_count,
                                       gint count);
gint data_collection_get_count (DataCollection* self);
static void app_window_real_update_common_action_availability (AppWindow* self,
                                                        Page* old_page,
                                                        Page* new_page);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
static void app_window_real_update_common_actions (AppWindow* self,
                                            Page* page,
                                            gint selected_count,
                                            gint count);
void app_window_decorate_undo_action (AppWindow* self);
void app_window_decorate_redo_action (AppWindow* self);
void app_window_update_menu_item_label (AppWindow* self,
                                        const gchar* id,
                                        const gchar* new_label);
GMenuModel* page_get_menubar (Page* self);
CommandManager* app_window_get_command_manager (void);
GType command_description_get_type (void) G_GNUC_CONST;
static void app_window_decorate_command_manager_action (AppWindow* self,
                                                 const gchar* name,
                                                 const gchar* prefix,
                                                 const gchar* default_explanation,
                                                 CommandDescription* desc);
gchar* command_description_get_name (CommandDescription* self);
#define RESOURCES_UNDO_MENU _ ("_Undo")
CommandDescription* command_manager_get_undo_description (CommandManager* self);
#define RESOURCES_REDO_MENU _ ("_Redo")
CommandDescription* command_manager_get_redo_description (CommandManager* self);
gboolean command_manager_undo (CommandManager* self);
gboolean command_manager_redo (CommandManager* self);
void view_collection_select_all (ViewCollection* self);
void view_collection_unselect_all (ViewCollection* self);
static gboolean app_window_real_configure_event (GtkWidget* base,
                                          GdkEventConfigure* event);
static void app_window_finalize (GObject * obj);

static const GActionEntry FULLSCREEN_WINDOW_entries[1] = {{"LeaveFullscreen", _fullscreen_window_on_close_gsimple_action_activate_callback}};
static const GActionEntry APP_WINDOW_common_actions[11] = {{"CommonAbout", _app_window_on_about_gsimple_action_activate_callback}, {"CommonQuit", _app_window_on_quit_gsimple_action_activate_callback}, {"CommonFullscreen", _app_window_on_fullscreen_gsimple_action_activate_callback}, {"CommonHelpContents", _app_window_on_help_contents_gsimple_action_activate_callback}, {"CommonHelpFAQ", _app_window_on_help_faq_gsimple_action_activate_callback}, {"CommonHelpReportProblem", _app_window_on_help_report_problem_gsimple_action_activate_callback}, {"CommonUndo", _app_window_on_undo_gsimple_action_activate_callback}, {"CommonRedo", _app_window_on_redo_gsimple_action_activate_callback}, {"CommonJumpToFile", _app_window_on_jump_to_file_gsimple_action_activate_callback}, {"CommonSelectAll", _app_window_on_select_all_gsimple_action_activate_callback}, {"CommonSelectNone", _app_window_on_select_none_gsimple_action_activate_callback}};
extern const gchar* RESOURCES_AUTHORS[6];

static void
_fullscreen_window_on_close_gsimple_action_activate_callback (GSimpleAction* action,
                                                              GVariant* parameter,
                                                              gpointer self)
{
#line 22 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_on_close ((FullscreenWindow*) self);
#line 737 "AppWindow.c"
}


static void
_fullscreen_window_update_toolbar_dismissal_gtk_tool_button_clicked (GtkToolButton* _sender,
                                                                     gpointer self)
{
#line 50 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_update_toolbar_dismissal ((FullscreenWindow*) self);
#line 747 "AppWindow.c"
}


static void
_fullscreen_window_hide_toolbar_slideshow_page_hide_toolbar (SlideshowPage* _sender,
                                                             gpointer self)
{
#line 65 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_hide_toolbar ((FullscreenWindow*) self);
#line 757 "AppWindow.c"
}


FullscreenWindow*
fullscreen_window_construct (GType object_type,
                             Page* page)
{
	FullscreenWindow * self = NULL;
#line 32 "/home/jens/Source/shotwell/src/AppWindow.vala"
	static const gchar* accels[2] = {"F11", NULL};
#line 768 "AppWindow.c"
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	GdkScreen* _tmp2_;
	GdkRectangle monitor = {0};
	GdkRectangle _tmp3_ = {0};
	GdkRectangle _tmp4_;
	gint _tmp5_;
	GdkRectangle _tmp6_;
	gint _tmp7_;
	ConfigFacade* _tmp8_;
	ConfigFacade* _tmp9_;
	GtkToggleToolButton* _tmp10_;
	GtkToggleToolButton* _tmp11_;
	GtkToggleToolButton* _tmp12_;
	GtkToggleToolButton* _tmp13_;
	gboolean _tmp14_;
	GtkToggleToolButton* _tmp15_;
	GtkToolButton* _tmp16_;
	GtkToolButton* _tmp17_;
	GtkToolButton* _tmp18_;
	GtkToolbar* _tmp19_;
	GtkToolbar* _tmp20_;
	GtkToolbar* _tmp21_;
	GtkToolbar* _tmp22_;
	GtkToolbar* _tmp23_;
	GtkToolbar* _tmp24_;
	GtkToolbar* _tmp27_;
	GtkToolButton* _tmp28_;
	GtkOverlay* _tmp29_;
	GtkOverlay* _tmp30_;
	GtkOverlay* _tmp31_;
	GtkToolbar* _tmp32_;
	GdkRectangle _tmp33_;
	gint _tmp34_;
	GdkRectangle _tmp35_;
	gint _tmp36_;
	gboolean _tmp37_ = FALSE;
	ConfigFacade* _tmp38_;
	ConfigFacade* _tmp39_;
	gboolean _tmp40_;
#line 26 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_PAGE (page), NULL);
#line 27 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = (FullscreenWindow*) page_window_construct (object_type);
#line 29 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_set_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), page);
#line 31 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_action_map_add_action_entries (G_TYPE_CHECK_INSTANCE_CAST (self, g_action_map_get_type (), GActionMap), FULLSCREEN_WINDOW_entries, G_N_ELEMENTS (FULLSCREEN_WINDOW_entries), self);
#line 33 "/home/jens/Source/shotwell/src/AppWindow.vala"
	application_set_accels_for_action ("win.LeaveFullscreen", accels, G_N_ELEMENTS (accels));
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_instance ();
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow));
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp2_);
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 38 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_get_monitor_geometry (self, &_tmp3_);
#line 38 "/home/jens/Source/shotwell/src/AppWindow.vala"
	monitor = _tmp3_;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = monitor;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _tmp4_.x;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = monitor;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = _tmp6_.y;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_move (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp5_, _tmp7_);
#line 41 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), (guint) 0);
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = config_facade_get_instance ();
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = _tmp8_;
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_dismissal_enabled = configuration_facade_get_pin_toolbar_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp9_);
#line 46 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = self->priv->pin_button;
#line 46 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_button_set_icon_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_tool_button_get_type (), GtkToolButton), "pin-toolbar");
#line 47 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = self->priv->pin_button;
#line 47 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_button_set_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_tool_button_get_type (), GtkToolButton), _ ("Pin Toolbar"));
#line 48 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = self->priv->pin_button;
#line 48 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_item_set_tooltip_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_tool_item_get_type (), GtkToolItem), _ ("Pin the toolbar open"));
#line 49 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = self->priv->pin_button;
#line 49 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = self->priv->is_toolbar_dismissal_enabled;
#line 49 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_toggle_tool_button_set_active (_tmp13_, !_tmp14_);
#line 50 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = self->priv->pin_button;
#line 50 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_tool_button_get_type (), GtkToolButton), "clicked", (GCallback) _fullscreen_window_update_toolbar_dismissal_gtk_tool_button_clicked, self, 0);
#line 52 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = self->priv->close_button;
#line 52 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_button_set_icon_name (_tmp16_, "view-restore");
#line 53 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = self->priv->close_button;
#line 53 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_item_set_tooltip_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_tool_item_get_type (), GtkToolItem), _ ("Leave fullscreen"));
#line 54 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp18_ = self->priv->close_button;
#line 54 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_actionable_set_action_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_actionable_get_type (), GtkActionable), "win.LeaveFullscreen");
#line 56 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp19_ = page_get_toolbar (page);
#line 56 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 56 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->toolbar = _tmp19_;
#line 57 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp20_ = self->priv->toolbar;
#line 57 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_toolbar_set_show_arrow (_tmp20_, FALSE);
#line 58 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp21_ = self->priv->toolbar;
#line 58 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_END);
#line 59 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp22_ = self->priv->toolbar;
#line 59 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 60 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp23_ = self->priv->toolbar;
#line 60 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_widget_get_type (), GtkWidget), "expand", FALSE, NULL);
#line 61 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp24_ = self->priv->toolbar;
#line 61 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_set_opacity (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget), RESOURCES_TRANSIENT_WINDOW_OPACITY);
#line 63 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (page, TYPE_SLIDESHOW_PAGE)) {
#line 65 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (page, TYPE_SLIDESHOW_PAGE, SlideshowPage), "hide-toolbar", (GCallback) _fullscreen_window_hide_toolbar_slideshow_page_hide_toolbar, self, 0);
#line 917 "AppWindow.c"
	} else {
		GtkToolbar* _tmp25_;
		GtkToggleToolButton* _tmp26_;
#line 68 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp25_ = self->priv->toolbar;
#line 68 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp26_ = self->priv->pin_button;
#line 68 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_toolbar_insert (_tmp25_, G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 927 "AppWindow.c"
	}
#line 71 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_set_cursor_hide_time (page, FULLSCREEN_WINDOW_TOOLBAR_DISMISSAL_SEC * 1000);
#line 72 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_start_cursor_hiding (page);
#line 74 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp27_ = self->priv->toolbar;
#line 74 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp28_ = self->priv->close_button;
#line 74 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_toolbar_insert (_tmp27_, G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 76 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp29_ = self->priv->overlay;
#line 76 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_widget_get_type (), GtkWidget));
#line 77 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp30_ = self->priv->overlay;
#line 77 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (page, gtk_widget_get_type (), GtkWidget));
#line 78 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp31_ = self->priv->overlay;
#line 78 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp32_ = self->priv->toolbar;
#line 78 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_overlay_add_overlay (_tmp31_, G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget));
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp33_ = monitor;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp34_ = _tmp33_.width;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp35_ = monitor;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp36_ = _tmp35_.height;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_default_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp34_, _tmp36_);
#line 86 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_fullscreen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 87 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 90 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_add_events (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), (gint) GDK_POINTER_MOTION_MASK);
#line 95 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp38_ = config_facade_get_instance ();
#line 95 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp39_ = _tmp38_;
#line 95 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp40_ = configuration_facade_get_display_toolbar (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 95 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp39_);
#line 95 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp40_) {
#line 95 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp37_ = TRUE;
#line 981 "AppWindow.c"
	} else {
		gboolean _tmp41_;
#line 96 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp41_ = self->priv->is_toolbar_dismissal_enabled;
#line 96 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp37_ = !_tmp41_;
#line 988 "AppWindow.c"
	}
#line 95 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp37_) {
#line 97 "/home/jens/Source/shotwell/src/AppWindow.vala"
		fullscreen_window_invoke_toolbar (self);
#line 994 "AppWindow.c"
	} else {
#line 99 "/home/jens/Source/shotwell/src/AppWindow.vala"
		fullscreen_window_hide_toolbar (self);
#line 998 "AppWindow.c"
	}
#line 103 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (page, gtk_widget_get_type (), GtkWidget));
#line 106 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_application_window_set_show_menubar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), FALSE);
#line 26 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self;
#line 1006 "AppWindow.c"
}


FullscreenWindow*
fullscreen_window_new (Page* page)
{
#line 26 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return fullscreen_window_construct (TYPE_FULLSCREEN_WINDOW, page);
#line 1015 "AppWindow.c"
}


void
fullscreen_window_disable_toolbar_dismissal (FullscreenWindow* self)
{
#line 109 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 110 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_dismissal_enabled = FALSE;
#line 1026 "AppWindow.c"
}


void
fullscreen_window_update_toolbar_dismissal (FullscreenWindow* self)
{
	GtkToggleToolButton* _tmp0_;
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 114 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->pin_button;
#line 114 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_dismissal_enabled = !gtk_toggle_tool_button_get_active (_tmp0_);
#line 1040 "AppWindow.c"
}


static void
fullscreen_window_get_monitor_geometry (FullscreenWindow* self,
                                        GdkRectangle* result)
{
	GdkRectangle monitor = {0};
	GdkScreen* _tmp0_;
	GdkScreen* _tmp1_;
	AppWindow* _tmp2_;
	AppWindow* _tmp3_;
	GdkWindow* _tmp4_;
	GdkRectangle _tmp5_ = {0};
#line 117 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = app_window_get_instance ();
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_screen_get_monitor_geometry (_tmp0_, gdk_screen_get_monitor_at_window (_tmp1_, _tmp4_), &_tmp5_);
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	monitor = _tmp5_;
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 123 "/home/jens/Source/shotwell/src/AppWindow.vala"
	*result = monitor;
#line 123 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return;
#line 1077 "AppWindow.c"
}


static gboolean
fullscreen_window_real_configure_event (GtkWidget* base,
                                        GdkEventConfigure* event)
{
	FullscreenWindow * self;
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
	gboolean _tmp0_;
#line 126 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 126 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 127 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_result_ = GTK_WIDGET_CLASS (fullscreen_window_parent_class)->configure_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), event);
#line 129 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->switched_to;
#line 129 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp0_) {
#line 1099 "AppWindow.c"
		Page* _tmp1_;
		Page* _tmp2_;
#line 130 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 130 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = _tmp1_;
#line 130 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_switched_to (_tmp2_);
#line 130 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp2_);
#line 131 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->switched_to = TRUE;
#line 1112 "AppWindow.c"
	}
#line 134 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _result_;
#line 134 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1118 "AppWindow.c"
}


static gboolean
fullscreen_window_real_key_press_event (GtkWidget* base,
                                        GdkEventKey* event)
{
	FullscreenWindow * self;
	gboolean result = FALSE;
	guint _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	AppWindow* _tmp3_;
	AppWindow* _tmp4_;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_;
#line 137 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 137 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = event->keyval;
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gdk_keyval_name (_tmp0_);
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (g_strcmp0 (_tmp1_, "Escape") == 0) {
#line 140 "/home/jens/Source/shotwell/src/AppWindow.vala"
		fullscreen_window_on_close (self);
#line 142 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 142 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1151 "AppWindow.c"
	}
#line 146 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (fullscreen_window_parent_class)->key_press_event != NULL) {
#line 146 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = GTK_WIDGET_CLASS (fullscreen_window_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), event);
#line 1157 "AppWindow.c"
	} else {
#line 146 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = FALSE;
#line 1161 "AppWindow.c"
	}
#line 146 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_) {
#line 147 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 147 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1169 "AppWindow.c"
	}
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = app_window_get_instance ();
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), "key-press-event", event, &_tmp5_);
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = _tmp5_;
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp6_;
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1185 "AppWindow.c"
}


static void
fullscreen_window_on_close (FullscreenWindow* self)
{
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gboolean _tmp2_;
	AppWindow* _tmp3_;
	AppWindow* _tmp4_;
#line 153 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 154 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = config_facade_get_instance ();
#line 154 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 154 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->is_toolbar_dismissal_enabled;
#line 154 "/home/jens/Source/shotwell/src/AppWindow.vala"
	configuration_facade_set_pin_toolbar_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_);
#line 154 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 155 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_hide_toolbar (self);
#line 157 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = app_window_get_instance ();
#line 157 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 157 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_end_fullscreen (_tmp4_);
#line 157 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 1219 "AppWindow.c"
}


void
fullscreen_window_close (FullscreenWindow* self)
{
#line 160 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 161 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_on_close (self);
#line 1230 "AppWindow.c"
}


static void
fullscreen_window_real_destroy (GtkWidget* base)
{
	FullscreenWindow * self;
	Page* page = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
#line 164 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 165 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 165 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = _tmp0_;
#line 166 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_clear_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 168 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = page;
#line 168 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 1253 "AppWindow.c"
		Page* _tmp2_;
		Page* _tmp3_;
#line 169 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = page;
#line 169 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_stop_cursor_hiding (_tmp2_);
#line 170 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 170 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_switching_from (_tmp3_);
#line 1264 "AppWindow.c"
	}
#line 173 "/home/jens/Source/shotwell/src/AppWindow.vala"
	GTK_WIDGET_CLASS (fullscreen_window_parent_class)->destroy (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget));
#line 164 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 1270 "AppWindow.c"
}


static gboolean
fullscreen_window_real_delete_event (GtkWidget* base,
                                     GdkEventAny* event)
{
	FullscreenWindow * self;
	gboolean result = FALSE;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
#line 176 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 176 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 177 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_on_close (self);
#line 178 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_instance ();
#line 178 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 178 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 178 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 180 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = TRUE;
#line 180 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1300 "AppWindow.c"
}


static gboolean
_fullscreen_window_on_check_toolbar_invocation_gsource_func (gpointer self)
{
	gboolean result;
	result = fullscreen_window_on_check_toolbar_invocation ((FullscreenWindow*) self);
#line 189 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1311 "AppWindow.c"
}


static gboolean
fullscreen_window_real_motion_notify_event (GtkWidget* base,
                                            GdkEventMotion* event)
{
	FullscreenWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
	gboolean _tmp3_ = FALSE;
#line 183 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 183 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 184 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->is_toolbar_shown;
#line 184 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp0_) {
#line 1331 "AppWindow.c"
		gboolean _tmp1_ = FALSE;
		gboolean _tmp2_;
#line 188 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->waiting_for_invoke;
#line 188 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (!_tmp2_) {
#line 188 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_tmp1_ = fullscreen_window_is_pointer_in_toolbar (self);
#line 1340 "AppWindow.c"
		} else {
#line 188 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_tmp1_ = FALSE;
#line 1344 "AppWindow.c"
		}
#line 188 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (_tmp1_) {
#line 189 "/home/jens/Source/shotwell/src/AppWindow.vala"
			g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) FULLSCREEN_WINDOW_TOOLBAR_INVOCATION_MSEC, _fullscreen_window_on_check_toolbar_invocation_gsource_func, g_object_ref (self), g_object_unref);
#line 190 "/home/jens/Source/shotwell/src/AppWindow.vala"
			self->priv->waiting_for_invoke = TRUE;
#line 1352 "AppWindow.c"
		}
	}
#line 194 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (fullscreen_window_parent_class)->motion_notify_event != NULL) {
#line 194 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = GTK_WIDGET_CLASS (fullscreen_window_parent_class)->motion_notify_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), event);
#line 1359 "AppWindow.c"
	} else {
#line 194 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = FALSE;
#line 1363 "AppWindow.c"
	}
#line 194 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp3_;
#line 194 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1369 "AppWindow.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 198 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self ? g_object_ref (self) : NULL;
#line 1378 "AppWindow.c"
}


static gboolean
fullscreen_window_is_pointer_in_toolbar (FullscreenWindow* self)
{
	gboolean result = FALSE;
	GdkDeviceManager* devmgr = NULL;
	GdkDisplay* _tmp0_;
	GdkDeviceManager* _tmp1_;
	GdkDeviceManager* _tmp2_;
	GdkDeviceManager* _tmp3_;
	gint py = 0;
	GdkDeviceManager* _tmp4_;
	GdkDevice* _tmp5_;
	gint _tmp6_ = 0;
	gint wy = 0;
	GtkToolbar* _tmp7_;
	GdkWindow* _tmp8_;
	gint _tmp9_ = 0;
	gint _tmp10_;
	gint _tmp11_;
#line 197 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_FULLSCREEN_WINDOW (self), FALSE);
#line 198 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_widget_get_display (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 198 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gdk_display_get_device_manager (_tmp0_);
#line 198 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 198 "/home/jens/Source/shotwell/src/AppWindow.vala"
	devmgr = _tmp2_;
#line 199 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = devmgr;
#line 199 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ == NULL) {
#line 200 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_debug ("AppWindow.vala:200: No device manager for display");
#line 202 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 202 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (devmgr);
#line 202 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1423 "AppWindow.c"
	}
#line 206 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = devmgr;
#line 206 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = gdk_device_manager_get_client_pointer (_tmp4_);
#line 206 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_device_get_position (_tmp5_, NULL, NULL, &_tmp6_);
#line 206 "/home/jens/Source/shotwell/src/AppWindow.vala"
	py = _tmp6_;
#line 209 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = self->priv->toolbar;
#line 209 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 209 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_window_get_geometry (_tmp8_, NULL, &_tmp9_, NULL, NULL);
#line 209 "/home/jens/Source/shotwell/src/AppWindow.vala"
	wy = _tmp9_;
#line 211 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = py;
#line 211 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = wy;
#line 211 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp10_ >= _tmp11_;
#line 211 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (devmgr);
#line 211 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1451 "AppWindow.c"
}


static gboolean
fullscreen_window_on_check_toolbar_invocation (FullscreenWindow* self)
{
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 214 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_FULLSCREEN_WINDOW (self), FALSE);
#line 215 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->waiting_for_invoke = FALSE;
#line 217 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->is_toolbar_shown;
#line 217 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 218 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 218 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1472 "AppWindow.c"
	}
#line 220 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!fullscreen_window_is_pointer_in_toolbar (self)) {
#line 221 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 221 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1480 "AppWindow.c"
	}
#line 223 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_invoke_toolbar (self);
#line 225 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = FALSE;
#line 225 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1488 "AppWindow.c"
}


static gboolean
_fullscreen_window_on_check_toolbar_dismissal_gsource_func (gpointer self)
{
	gboolean result;
	result = fullscreen_window_on_check_toolbar_dismissal ((FullscreenWindow*) self);
#line 233 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1499 "AppWindow.c"
}


static void
fullscreen_window_invoke_toolbar (FullscreenWindow* self)
{
	GtkToolbar* _tmp0_;
#line 228 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 229 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->toolbar;
#line 229 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 231 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_shown = TRUE;
#line 233 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) FULLSCREEN_WINDOW_TOOLBAR_CHECK_DISMISSAL_MSEC, _fullscreen_window_on_check_toolbar_dismissal_gsource_func, g_object_ref (self), g_object_unref);
#line 1517 "AppWindow.c"
}


static gboolean
fullscreen_window_on_check_toolbar_dismissal (FullscreenWindow* self)
{
	gboolean result = FALSE;
	gboolean _tmp0_;
	gboolean _tmp1_;
	time_t _tmp2_;
	time_t now = 0;
	time_t _tmp4_;
	time_t _tmp5_;
	time_t _tmp6_;
	time_t _tmp7_;
	time_t _tmp8_;
#line 236 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_FULLSCREEN_WINDOW (self), FALSE);
#line 237 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->is_toolbar_shown;
#line 237 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp0_) {
#line 238 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 238 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1544 "AppWindow.c"
	}
#line 241 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->priv->is_toolbar_dismissal_enabled;
#line 241 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp1_) {
#line 242 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 242 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1554 "AppWindow.c"
	}
#line 245 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (fullscreen_window_is_pointer_in_toolbar (self)) {
#line 246 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->left_toolbar_time = (time_t) 0;
#line 248 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 248 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1564 "AppWindow.c"
	}
#line 252 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->left_toolbar_time;
#line 252 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ == ((time_t) 0)) {
#line 1570 "AppWindow.c"
		time_t _tmp3_;
#line 253 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = time (NULL);
#line 253 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->left_toolbar_time = _tmp3_;
#line 255 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 255 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1580 "AppWindow.c"
	}
#line 259 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = time (NULL);
#line 259 "/home/jens/Source/shotwell/src/AppWindow.vala"
	now = _tmp4_;
#line 260 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = now;
#line 260 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = self->priv->left_toolbar_time;
#line 260 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_vala_assert (_tmp5_ >= _tmp6_, "now >= left_toolbar_time");
#line 262 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = now;
#line 262 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = self->priv->left_toolbar_time;
#line 262 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if ((_tmp7_ - _tmp8_) < ((time_t) FULLSCREEN_WINDOW_TOOLBAR_DISMISSAL_SEC)) {
#line 263 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 263 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1602 "AppWindow.c"
	}
#line 265 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_hide_toolbar (self);
#line 267 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = FALSE;
#line 267 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1610 "AppWindow.c"
}


static void
fullscreen_window_hide_toolbar (FullscreenWindow* self)
{
	GtkToolbar* _tmp0_;
#line 270 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 271 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->toolbar;
#line 271 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 272 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_shown = FALSE;
#line 1626 "AppWindow.c"
}


static void
fullscreen_window_class_init (FullscreenWindowClass * klass)
{
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_type_class_add_private (klass, sizeof (FullscreenWindowPrivate));
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->configure_event = (gboolean (*) (GtkWidget *, GdkEventConfigure*)) fullscreen_window_real_configure_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) fullscreen_window_real_key_press_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->destroy = (void (*) (GtkWidget *)) fullscreen_window_real_destroy;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->delete_event = (gboolean (*) (GtkWidget *, GdkEventAny*)) fullscreen_window_real_delete_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->motion_notify_event = (gboolean (*) (GtkWidget *, GdkEventMotion*)) fullscreen_window_real_motion_notify_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = fullscreen_window_finalize;
#line 1649 "AppWindow.c"
}


static void
fullscreen_window_instance_init (FullscreenWindow * self)
{
	GtkOverlay* _tmp0_;
	GtkToolButton* _tmp1_;
	GtkToggleToolButton* _tmp2_;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv = FULLSCREEN_WINDOW_GET_PRIVATE (self);
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = (GtkOverlay*) gtk_overlay_new ();
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp0_);
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->overlay = _tmp0_;
#line 13 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->toolbar = NULL;
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp1_);
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->close_button = _tmp1_;
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = (GtkToggleToolButton*) gtk_toggle_tool_button_new ();
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp2_);
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->pin_button = _tmp2_;
#line 16 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_shown = FALSE;
#line 17 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->waiting_for_invoke = FALSE;
#line 18 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->left_toolbar_time = (time_t) 0;
#line 19 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->switched_to = FALSE;
#line 1689 "AppWindow.c"
}


static void
fullscreen_window_finalize (GObject * obj)
{
	FullscreenWindow * self;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->overlay);
#line 13 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->close_button);
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->pin_button);
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (fullscreen_window_parent_class)->finalize (obj);
#line 1709 "AppWindow.c"
}


GType
fullscreen_window_get_type (void)
{
	static volatile gsize fullscreen_window_type_id__volatile = 0;
	if (g_once_init_enter (&fullscreen_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FullscreenWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) fullscreen_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FullscreenWindow), 0, (GInstanceInitFunc) fullscreen_window_instance_init, NULL };
		GType fullscreen_window_type_id;
		fullscreen_window_type_id = g_type_register_static (TYPE_PAGE_WINDOW, "FullscreenWindow", &g_define_type_info, 0);
		g_once_init_leave (&fullscreen_window_type_id__volatile, fullscreen_window_type_id);
	}
	return fullscreen_window_type_id__volatile;
}


static void
page_window_real_switched_pages (PageWindow* self,
                                 Page* old_page,
                                 Page* new_page)
{
#line 287 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 287 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 1736 "AppWindow.c"
}


void
page_window_switched_pages (PageWindow* self,
                            Page* old_page,
                            Page* new_page)
{
#line 287 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 287 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_GET_CLASS (self)->switched_pages (self, old_page, new_page);
#line 1749 "AppWindow.c"
}


PageWindow*
page_window_construct (GType object_type)
{
	PageWindow * self = NULL;
	Application* _tmp0_;
	Application* _tmp1_;
	GtkApplication* _tmp2_;
	GtkApplication* _tmp3_;
#line 291 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = application_get_instance ();
#line 291 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 291 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = application_get_system_app (_tmp1_);
#line 291 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 291 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = (PageWindow*) g_object_new (object_type, "application", _tmp3_, NULL);
#line 291 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 291 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_application_unref0 (_tmp1_);
#line 294 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_add_events (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), (gint) ((GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK) | GDK_STRUCTURE_MASK));
#line 296 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_application_window_set_show_menubar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), TRUE);
#line 290 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self;
#line 1781 "AppWindow.c"
}


Page*
page_window_get_current_page (PageWindow* self)
{
	Page* result = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
#line 299 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_PAGE_WINDOW (self), NULL);
#line 300 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 300 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 300 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 300 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1801 "AppWindow.c"
}


static void
page_window_real_set_current_page (PageWindow* self,
                                   Page* page)
{
	Page* _tmp0_;
	Page* old_page = NULL;
	Page* _tmp2_;
	Page* _tmp3_;
	Page* _tmp4_;
	Page* _tmp5_;
#line 303 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 304 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 304 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 1821 "AppWindow.c"
		Page* _tmp1_;
#line 305 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->current_page;
#line 305 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_clear_container (_tmp1_);
#line 1827 "AppWindow.c"
	}
#line 307 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->current_page;
#line 307 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 307 "/home/jens/Source/shotwell/src/AppWindow.vala"
	old_page = _tmp3_;
#line 308 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _g_object_ref0 (page);
#line 308 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->current_page);
#line 308 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->current_page = _tmp4_;
#line 309 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = self->priv->current_page;
#line 309 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_set_container (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 311 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_switched_pages (self, old_page, page);
#line 303 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (old_page);
#line 1849 "AppWindow.c"
}


void
page_window_set_current_page (PageWindow* self,
                              Page* page)
{
#line 303 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 303 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_GET_CLASS (self)->set_current_page (self, page);
#line 1861 "AppWindow.c"
}


static void
page_window_real_clear_current_page (PageWindow* self)
{
	Page* _tmp0_;
	Page* old_page = NULL;
	Page* _tmp2_;
	Page* _tmp3_;
#line 315 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 315 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 1876 "AppWindow.c"
		Page* _tmp1_;
#line 316 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->current_page;
#line 316 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_clear_container (_tmp1_);
#line 1882 "AppWindow.c"
	}
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->current_page;
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
	old_page = _tmp3_;
#line 319 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->current_page);
#line 319 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->current_page = NULL;
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_switched_pages (self, old_page, NULL);
#line 314 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (old_page);
#line 1898 "AppWindow.c"
}


void
page_window_clear_current_page (PageWindow* self)
{
#line 314 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 314 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_GET_CLASS (self)->clear_current_page (self);
#line 1909 "AppWindow.c"
}


static gboolean
page_window_real_key_press_event (GtkWidget* base,
                                  GdkEventKey* event)
{
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GtkWidget* _tmp1_;
	gboolean _tmp4_ = FALSE;
	Page* _tmp5_;
	gboolean _tmp7_ = FALSE;
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 325 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 325 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_entry_get_type ())) {
#line 1932 "AppWindow.c"
		GtkWidget* _tmp2_;
		gboolean _tmp3_ = FALSE;
#line 325 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 325 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_emit_by_name (_tmp2_, "key-press-event", event, &_tmp3_);
#line 325 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp3_;
#line 1941 "AppWindow.c"
	} else {
#line 325 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 1945 "AppWindow.c"
	}
#line 325 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 326 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 326 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1953 "AppWindow.c"
	}
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = self->priv->current_page;
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_ != NULL) {
#line 1959 "AppWindow.c"
		Page* _tmp6_;
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = self->priv->current_page;
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_notify_app_key_pressed (_tmp6_, event);
#line 1965 "AppWindow.c"
	} else {
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = FALSE;
#line 1969 "AppWindow.c"
	}
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp4_) {
#line 329 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 329 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1977 "AppWindow.c"
	}
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->key_press_event != NULL) {
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = GTK_WIDGET_CLASS (page_window_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), event);
#line 1983 "AppWindow.c"
	} else {
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = FALSE;
#line 1987 "AppWindow.c"
	}
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp7_;
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1993 "AppWindow.c"
}


static gboolean
page_window_real_key_release_event (GtkWidget* base,
                                    GdkEventKey* event)
{
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GtkWidget* _tmp1_;
	gboolean _tmp4_ = FALSE;
	Page* _tmp5_;
	gboolean _tmp7_ = FALSE;
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 335 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 335 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_entry_get_type ())) {
#line 2016 "AppWindow.c"
		GtkWidget* _tmp2_;
		gboolean _tmp3_ = FALSE;
#line 335 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 335 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_emit_by_name (_tmp2_, "key-release-event", event, &_tmp3_);
#line 335 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp3_;
#line 2025 "AppWindow.c"
	} else {
#line 335 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 2029 "AppWindow.c"
	}
#line 335 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 336 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 336 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 2037 "AppWindow.c"
	}
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = self->priv->current_page;
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_ != NULL) {
#line 2043 "AppWindow.c"
		Page* _tmp6_;
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = self->priv->current_page;
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_notify_app_key_released (_tmp6_, event);
#line 2049 "AppWindow.c"
	} else {
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = FALSE;
#line 2053 "AppWindow.c"
	}
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp4_) {
#line 339 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 339 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 2061 "AppWindow.c"
	}
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->key_release_event != NULL) {
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = GTK_WIDGET_CLASS (page_window_parent_class)->key_release_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), event);
#line 2067 "AppWindow.c"
	} else {
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = FALSE;
#line 2071 "AppWindow.c"
	}
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp7_;
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2077 "AppWindow.c"
}


static gboolean
page_window_real_focus_in_event (GtkWidget* base,
                                 GdkEventFocus* event)
{
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	Page* _tmp1_;
	gboolean _tmp3_ = FALSE;
#line 344 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 344 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->priv->current_page;
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 2098 "AppWindow.c"
		Page* _tmp2_;
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->current_page;
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = page_notify_app_focus_in (_tmp2_, event);
#line 2104 "AppWindow.c"
	} else {
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 2108 "AppWindow.c"
	}
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 346 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 346 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 2116 "AppWindow.c"
	}
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->focus_in_event != NULL) {
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = GTK_WIDGET_CLASS (page_window_parent_class)->focus_in_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), event);
#line 2122 "AppWindow.c"
	} else {
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = FALSE;
#line 2126 "AppWindow.c"
	}
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp3_;
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2132 "AppWindow.c"
}


static gboolean
page_window_real_focus_out_event (GtkWidget* base,
                                  GdkEventFocus* event)
{
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	Page* _tmp1_;
	gboolean _tmp3_ = FALSE;
#line 351 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 351 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->priv->current_page;
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 2153 "AppWindow.c"
		Page* _tmp2_;
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->current_page;
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = page_notify_app_focus_out (_tmp2_, event);
#line 2159 "AppWindow.c"
	} else {
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 2163 "AppWindow.c"
	}
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 353 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 353 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 2171 "AppWindow.c"
	}
#line 355 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->focus_out_event != NULL) {
#line 355 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = GTK_WIDGET_CLASS (page_window_parent_class)->focus_out_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), event);
#line 2177 "AppWindow.c"
	} else {
#line 355 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = FALSE;
#line 2181 "AppWindow.c"
	}
#line 355 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp3_;
#line 355 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2187 "AppWindow.c"
}


static gboolean
page_window_real_configure_event (GtkWidget* base,
                                  GdkEventConfigure* event)
{
	PageWindow * self;
	gboolean result = FALSE;
	Page* _tmp0_;
	gboolean _tmp2_ = FALSE;
#line 358 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 358 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 359 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 359 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 2207 "AppWindow.c"
		Page* _tmp1_;
#line 360 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->current_page;
#line 360 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (page_notify_configure_event (_tmp1_, event)) {
#line 361 "/home/jens/Source/shotwell/src/AppWindow.vala"
			result = TRUE;
#line 361 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return result;
#line 2217 "AppWindow.c"
		}
	}
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->configure_event != NULL) {
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = GTK_WIDGET_CLASS (page_window_parent_class)->configure_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), event);
#line 2224 "AppWindow.c"
	} else {
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = FALSE;
#line 2228 "AppWindow.c"
	}
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp2_;
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2234 "AppWindow.c"
}


void
page_window_set_busy_cursor (PageWindow* self)
{
	gint _tmp0_;
	GdkDisplay* display = NULL;
	GdkWindow* _tmp1_;
	GdkDisplay* _tmp2_;
	GdkDisplay* _tmp3_;
	GdkCursor* cursor = NULL;
	GdkDisplay* _tmp4_;
	GdkCursor* _tmp5_;
	GdkWindow* _tmp6_;
	GdkCursor* _tmp7_;
#line 367 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 368 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->busy_counter;
#line 368 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->busy_counter = _tmp0_ + 1;
#line 368 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ > 0) {
#line 369 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 2261 "AppWindow.c"
	}
#line 371 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 371 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = gdk_window_get_display (_tmp1_);
#line 371 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 371 "/home/jens/Source/shotwell/src/AppWindow.vala"
	display = _tmp3_;
#line 372 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = display;
#line 372 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = gdk_cursor_new_for_display (_tmp4_, GDK_WATCH);
#line 372 "/home/jens/Source/shotwell/src/AppWindow.vala"
	cursor = _tmp5_;
#line 373 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 373 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = cursor;
#line 373 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_window_set_cursor (_tmp6_, _tmp7_);
#line 374 "/home/jens/Source/shotwell/src/AppWindow.vala"
	spin_event_loop ();
#line 367 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (cursor);
#line 367 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (display);
#line 2289 "AppWindow.c"
}


void
page_window_set_normal_cursor (PageWindow* self)
{
	gint _tmp0_;
	GdkDisplay* display = NULL;
	GdkWindow* _tmp3_;
	GdkDisplay* _tmp4_;
	GdkDisplay* _tmp5_;
	GdkCursor* cursor = NULL;
	GdkDisplay* _tmp6_;
	GdkCursor* _tmp7_;
	GdkWindow* _tmp8_;
	GdkCursor* _tmp9_;
#line 377 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 378 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->busy_counter;
#line 378 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ <= 0) {
#line 379 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->busy_counter = 0;
#line 380 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 2316 "AppWindow.c"
	} else {
		gint _tmp1_;
		gint _tmp2_;
#line 381 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->busy_counter;
#line 381 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->busy_counter = _tmp1_ - 1;
#line 381 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->busy_counter;
#line 381 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (_tmp2_ > 0) {
#line 382 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return;
#line 2330 "AppWindow.c"
		}
	}
#line 385 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 385 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = gdk_window_get_display (_tmp3_);
#line 385 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 385 "/home/jens/Source/shotwell/src/AppWindow.vala"
	display = _tmp5_;
#line 386 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = display;
#line 386 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = gdk_cursor_new_for_display (_tmp6_, GDK_LEFT_PTR);
#line 386 "/home/jens/Source/shotwell/src/AppWindow.vala"
	cursor = _tmp7_;
#line 387 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 387 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = cursor;
#line 387 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_window_set_cursor (_tmp8_, _tmp9_);
#line 388 "/home/jens/Source/shotwell/src/AppWindow.vala"
	spin_event_loop ();
#line 377 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (cursor);
#line 377 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (display);
#line 2359 "AppWindow.c"
}


static void
page_window_class_init (PageWindowClass * klass)
{
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_parent_class = g_type_class_peek_parent (klass);
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_type_class_add_private (klass, sizeof (PageWindowPrivate));
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->switched_pages = (void (*) (PageWindow *, Page*, Page*)) page_window_real_switched_pages;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->set_current_page = (void (*) (PageWindow *, Page*)) page_window_real_set_current_page;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->clear_current_page = (void (*) (PageWindow *)) page_window_real_clear_current_page;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) page_window_real_key_press_event;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->key_release_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) page_window_real_key_release_event;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->focus_in_event = (gboolean (*) (GtkWidget *, GdkEventFocus*)) page_window_real_focus_in_event;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->focus_out_event = (gboolean (*) (GtkWidget *, GdkEventFocus*)) page_window_real_focus_out_event;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->configure_event = (gboolean (*) (GtkWidget *, GdkEventConfigure*)) page_window_real_configure_event;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = page_window_finalize;
#line 2388 "AppWindow.c"
}


static void
page_window_instance_init (PageWindow * self)
{
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv = PAGE_WINDOW_GET_PRIVATE (self);
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->current_page = NULL;
#line 285 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->busy_counter = 0;
#line 2401 "AppWindow.c"
}


static void
page_window_finalize (GObject * obj)
{
	PageWindow * self;
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PAGE_WINDOW, PageWindow);
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->current_page);
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (page_window_parent_class)->finalize (obj);
#line 2415 "AppWindow.c"
}


GType
page_window_get_type (void)
{
	static volatile gsize page_window_type_id__volatile = 0;
	if (g_once_init_enter (&page_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PageWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) page_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PageWindow), 0, (GInstanceInitFunc) page_window_instance_init, NULL };
		GType page_window_type_id;
		page_window_type_id = g_type_register_static (gtk_application_window_get_type (), "PageWindow", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&page_window_type_id__volatile, page_window_type_id);
	}
	return page_window_type_id__volatile;
}


static void
_app_window_on_about_gsimple_action_activate_callback (GSimpleAction* action,
                                                       GVariant* parameter,
                                                       gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_about ((AppWindow*) self);
#line 2440 "AppWindow.c"
}


static void
_app_window_on_quit_gsimple_action_activate_callback (GSimpleAction* action,
                                                      GVariant* parameter,
                                                      gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_quit ((AppWindow*) self);
#line 2451 "AppWindow.c"
}


static void
_app_window_on_fullscreen_gsimple_action_activate_callback (GSimpleAction* action,
                                                            GVariant* parameter,
                                                            gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_fullscreen ((AppWindow*) self);
#line 2462 "AppWindow.c"
}


static void
_app_window_on_help_contents_gsimple_action_activate_callback (GSimpleAction* action,
                                                               GVariant* parameter,
                                                               gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_help_contents ((AppWindow*) self);
#line 2473 "AppWindow.c"
}


static void
_app_window_on_help_faq_gsimple_action_activate_callback (GSimpleAction* action,
                                                          GVariant* parameter,
                                                          gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_help_faq ((AppWindow*) self);
#line 2484 "AppWindow.c"
}


static void
_app_window_on_help_report_problem_gsimple_action_activate_callback (GSimpleAction* action,
                                                                     GVariant* parameter,
                                                                     gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_help_report_problem ((AppWindow*) self);
#line 2495 "AppWindow.c"
}


static void
_app_window_on_undo_gsimple_action_activate_callback (GSimpleAction* action,
                                                      GVariant* parameter,
                                                      gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_undo ((AppWindow*) self);
#line 2506 "AppWindow.c"
}


static void
_app_window_on_redo_gsimple_action_activate_callback (GSimpleAction* action,
                                                      GVariant* parameter,
                                                      gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_redo ((AppWindow*) self);
#line 2517 "AppWindow.c"
}


static void
_app_window_on_jump_to_file_gsimple_action_activate_callback (GSimpleAction* action,
                                                              GVariant* parameter,
                                                              gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_jump_to_file ((AppWindow*) self);
#line 2528 "AppWindow.c"
}


static void
_app_window_on_select_all_gsimple_action_activate_callback (GSimpleAction* action,
                                                            GVariant* parameter,
                                                            gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_select_all ((AppWindow*) self);
#line 2539 "AppWindow.c"
}


static void
_app_window_on_select_none_gsimple_action_activate_callback (GSimpleAction* action,
                                                             GVariant* parameter,
                                                             gpointer self)
{
#line 456 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_select_none ((AppWindow*) self);
#line 2550 "AppWindow.c"
}


static void
_app_window_on_command_manager_altered_command_manager_altered (CommandManager* _sender,
                                                                gboolean can_undo,
                                                                gboolean can_redo,
                                                                gpointer self)
{
#line 437 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_command_manager_altered ((AppWindow*) self);
#line 2562 "AppWindow.c"
}


AppWindow*
app_window_construct (GType object_type)
{
	AppWindow * self = NULL;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	Dimensions _tmp10_;
	gint _tmp11_;
	Dimensions _tmp12_;
	gint _tmp13_;
	gboolean _tmp14_;
	CommandManager* _tmp15_;
	CommandManager* _tmp16_;
	CommandManager* _tmp17_;
	GtkCssProvider* provider = NULL;
	GtkCssProvider* _tmp18_;
	GError * _inner_error_ = NULL;
#line 414 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = (AppWindow*) page_window_construct (object_type);
#line 416 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_instance;
#line 416 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_vala_assert (_tmp0_ == NULL, "instance == null");
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (self);
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (app_window_instance);
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_instance = _tmp1_;
#line 419 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), RESOURCES_APP_TITLE);
#line 420 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_default_icon_name ("shotwell");
#line 423 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, TYPE_LIBRARY_WINDOW)) {
#line 2601 "AppWindow.c"
		ConfigFacade* _tmp2_;
		ConfigFacade* _tmp3_;
		gboolean _tmp4_ = FALSE;
		Dimensions _tmp5_ = {0};
#line 424 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = config_facade_get_instance ();
#line 424 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp2_;
#line 424 "/home/jens/Source/shotwell/src/AppWindow.vala"
		configuration_facade_get_library_window_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp4_, &_tmp5_);
#line 424 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->maximized = _tmp4_;
#line 424 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions = _tmp5_;
#line 424 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp3_);
#line 2618 "AppWindow.c"
	} else {
		ConfigFacade* _tmp6_;
		ConfigFacade* _tmp7_;
		gboolean _tmp8_ = FALSE;
		Dimensions _tmp9_ = {0};
#line 426 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (self, TYPE_DIRECT_WINDOW), "this is DirectWindow");
#line 427 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = config_facade_get_instance ();
#line 427 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = _tmp6_;
#line 427 "/home/jens/Source/shotwell/src/AppWindow.vala"
		configuration_facade_get_direct_window_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp8_, &_tmp9_);
#line 427 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->maximized = _tmp8_;
#line 427 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions = _tmp9_;
#line 427 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp7_);
#line 2638 "AppWindow.c"
	}
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = self->dimensions;
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = _tmp10_.width;
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = self->dimensions;
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = _tmp12_.height;
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_default_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp11_, _tmp13_);
#line 432 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = self->maximized;
#line 432 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp14_) {
#line 433 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_window_maximize (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 2656 "AppWindow.c"
	}
#line 435 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = app_window_command_manager;
#line 435 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_vala_assert (_tmp15_ == NULL, "command_manager == null");
#line 436 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = command_manager_new (COMMAND_MANAGER_DEFAULT_DEPTH);
#line 436 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_command_manager_unref0 (app_window_command_manager);
#line 436 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_command_manager = _tmp16_;
#line 437 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = app_window_command_manager;
#line 437 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_signal_connect_object (_tmp17_, "altered", (GCallback) _app_window_on_command_manager_altered_command_manager_altered, self, 0);
#line 445 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_add_actions (self);
#line 447 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp18_ = gtk_css_provider_new ();
#line 447 "/home/jens/Source/shotwell/src/AppWindow.vala"
	provider = _tmp18_;
#line 2678 "AppWindow.c"
	{
		GdkScreen* _tmp19_;
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_css_provider_load_from_data (provider, RESOURCES_CUSTOM_CSS, (gssize) -1, &_inner_error_);
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2685 "AppWindow.c"
			goto __catch238_g_error;
		}
#line 450 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp19_ = gdk_screen_get_default ();
#line 450 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_style_context_add_provider_for_screen (_tmp19_, G_TYPE_CHECK_INSTANCE_CAST (provider, gtk_style_provider_get_type (), GtkStyleProvider), (guint) GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
#line 2692 "AppWindow.c"
	}
	goto __finally238;
	__catch238_g_error:
	{
		GError* err = NULL;
		GError* _tmp20_;
		const gchar* _tmp21_;
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 452 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp20_ = err;
#line 452 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp21_ = _tmp20_->message;
#line 452 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_debug ("AppWindow.vala:452: Unable to load custom CSS: %s", _tmp21_);
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 2712 "AppWindow.c"
	}
	__finally238:
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (provider);
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 448 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return NULL;
#line 2725 "AppWindow.c"
	}
#line 414 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (provider);
#line 414 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self;
#line 2731 "AppWindow.c"
}


static void
app_window_real_on_fullscreen (AppWindow* self)
{
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_critical ("Type `%s' does not implement abstract method `app_window_on_fullscreen'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return;
#line 2742 "AppWindow.c"
}


void
app_window_on_fullscreen (AppWindow* self)
{
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->on_fullscreen (self);
#line 2753 "AppWindow.c"
}


gboolean
app_window_has_instance (void)
{
	gboolean result = FALSE;
	AppWindow* _tmp0_;
#line 473 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_instance;
#line 473 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp0_ != NULL;
#line 473 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2768 "AppWindow.c"
}


AppWindow*
app_window_get_instance (void)
{
	AppWindow* result = NULL;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
#line 477 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_instance;
#line 477 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 477 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 477 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2786 "AppWindow.c"
}


FullscreenWindow*
app_window_get_fullscreen (void)
{
	FullscreenWindow* result = NULL;
	FullscreenWindow* _tmp0_;
	FullscreenWindow* _tmp1_;
#line 481 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_fullscreen_window;
#line 481 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 481 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 481 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2804 "AppWindow.c"
}


GtkBuilder*
app_window_create_builder (const gchar* glade_filename,
                           void* user)
{
	GtkBuilder* result = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	GError * _inner_error_ = NULL;
#line 484 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (glade_filename != NULL, NULL);
#line 485 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_builder_new ();
#line 485 "/home/jens/Source/shotwell/src/AppWindow.vala"
	builder = _tmp0_;
#line 2822 "AppWindow.c"
	{
		gchar* _tmp1_;
		gchar* _tmp2_;
#line 487 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = resources_get_ui (glade_filename);
#line 487 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = _tmp1_;
#line 487 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_builder_add_from_resource (builder, _tmp2_, &_inner_error_);
#line 487 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp2_);
#line 487 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2836 "AppWindow.c"
			goto __catch239_g_error;
		}
	}
	goto __finally239;
	__catch239_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_error_ = _inner_error_;
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 489 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _error_;
#line 489 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp3_->message;
#line 489 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_warning ("AppWindow.vala:489: Unable to create Gtk.Builder: %s\n", _tmp4_);
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (_error_);
#line 2858 "AppWindow.c"
	}
	__finally239:
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (builder);
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 486 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return NULL;
#line 2871 "AppWindow.c"
	}
#line 492 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_builder_connect_signals (builder, user);
#line 494 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = builder;
#line 494 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2879 "AppWindow.c"
}


void
app_window_error_message (const gchar* message,
                          GtkWindow* parent)
{
#line 497 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (message != NULL);
#line 497 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent));
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_error_message_with_title (RESOURCES_APP_TITLE, message, parent, TRUE);
#line 2893 "AppWindow.c"
}


void
app_window_error_message_with_title (const gchar* title,
                                     const gchar* message,
                                     GtkWindow* parent,
                                     gboolean should_escape)
{
	GtkWindow* _tmp0_ = NULL;
	GtkMessageDialog* dialog = NULL;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkMessageDialog* _tmp5_;
	GtkMessageDialog* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
#line 501 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (title != NULL);
#line 501 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (message != NULL);
#line 501 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent));
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (parent != NULL) {
#line 2919 "AppWindow.c"
		GtkWindow* _tmp1_;
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _g_object_ref0 (parent);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp1_;
#line 2927 "AppWindow.c"
	} else {
		AppWindow* _tmp2_;
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = app_window_get_instance ();
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow);
#line 2936 "AppWindow.c"
	}
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = build_alert_body_text (title, message, should_escape);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", _tmp4_);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp5_);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = _tmp5_;
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp4_);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp6_;
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = build_alert_body_text (title, message, should_escape);
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_;
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (dialog, _tmp8_);
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp8_);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (dialog, "use-markup", TRUE, NULL);
#line 512 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 513 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 501 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 501 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 2970 "AppWindow.c"
}


gboolean
app_window_negate_affirm_question (const gchar* message,
                                   const gchar* negative,
                                   const gchar* affirmative,
                                   const gchar* title,
                                   GtkWindow* parent)
{
	gboolean result = FALSE;
	GtkWindow* _tmp0_ = NULL;
	GtkMessageDialog* dialog = NULL;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkMessageDialog* _tmp5_;
	GtkMessageDialog* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gboolean response = FALSE;
#line 516 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, FALSE);
#line 516 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (negative != NULL, FALSE);
#line 516 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, FALSE);
#line 516 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), FALSE);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (parent != NULL) {
#line 3001 "AppWindow.c"
		GtkWindow* _tmp1_;
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _g_object_ref0 (parent);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp1_;
#line 3009 "AppWindow.c"
	} else {
		AppWindow* _tmp2_;
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = app_window_get_instance ();
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow);
#line 3018 "AppWindow.c"
	}
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = build_alert_body_text (title, message, TRUE);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp4_);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp5_);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = _tmp5_;
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp4_);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp6_;
#line 521 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = build_alert_body_text (title, message, TRUE);
#line 521 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_;
#line 521 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (dialog, _tmp8_);
#line 521 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp8_);
#line 522 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), negative, GTK_RESPONSE_NO, affirmative, GTK_RESPONSE_YES, NULL);
#line 523 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_urgency_hint (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), TRUE);
#line 525 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog)) == ((gint) GTK_RESPONSE_YES);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 529 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = response;
#line 529 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 529 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 529 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 3058 "AppWindow.c"
}


GtkResponseType
app_window_negate_affirm_cancel_question (const gchar* message,
                                          const gchar* negative,
                                          const gchar* affirmative,
                                          const gchar* title,
                                          GtkWindow* parent)
{
	GtkResponseType result = 0;
	GtkWindow* _tmp0_ = NULL;
	GtkMessageDialog* dialog = NULL;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkMessageDialog* _tmp5_;
	GtkMessageDialog* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gint response = 0;
#line 532 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, 0);
#line 532 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (negative != NULL, 0);
#line 532 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, 0);
#line 532 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), 0);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (parent != NULL) {
#line 3089 "AppWindow.c"
		GtkWindow* _tmp1_;
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _g_object_ref0 (parent);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp1_;
#line 3097 "AppWindow.c"
	} else {
		AppWindow* _tmp2_;
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = app_window_get_instance ();
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow);
#line 3106 "AppWindow.c"
	}
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = build_alert_body_text (title, message, TRUE);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp4_);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp5_);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = _tmp5_;
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp4_);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp6_;
#line 537 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), negative, GTK_RESPONSE_NO, affirmative, GTK_RESPONSE_YES, _ ("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = build_alert_body_text (title, message, TRUE);
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_;
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (dialog, _tmp8_);
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp8_);
#line 542 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (dialog, "use-markup", TRUE, NULL);
#line 544 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 548 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = (GtkResponseType) response;
#line 548 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 548 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 548 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 3146 "AppWindow.c"
}


GtkResponseType
app_window_affirm_cancel_question (const gchar* message,
                                   const gchar* affirmative,
                                   const gchar* title,
                                   GtkWindow* parent)
{
	GtkResponseType result = 0;
	GtkWindow* _tmp0_ = NULL;
	GtkMessageDialog* dialog = NULL;
	GtkMessageDialog* _tmp3_;
	GtkMessageDialog* _tmp4_;
	GtkMessageDialog* _tmp5_;
	const gchar* _tmp6_ = NULL;
	GtkMessageDialog* _tmp7_;
	GtkMessageDialog* _tmp8_;
	gint response = 0;
	GtkMessageDialog* _tmp9_;
	GtkMessageDialog* _tmp10_;
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, 0);
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, 0);
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), 0);
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (parent != NULL) {
#line 3176 "AppWindow.c"
		GtkWindow* _tmp1_;
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _g_object_ref0 (parent);
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp1_;
#line 3184 "AppWindow.c"
	} else {
		AppWindow* _tmp2_;
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = app_window_get_instance ();
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow);
#line 3193 "AppWindow.c"
	}
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", message);
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp3_);
#line 553 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp3_;
#line 556 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = dialog;
#line 556 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (_tmp4_, message);
#line 557 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = dialog;
#line 557 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (_tmp5_, "use-markup", TRUE, NULL);
#line 558 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (title != NULL) {
#line 558 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = title;
#line 3213 "AppWindow.c"
	} else {
#line 558 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = RESOURCES_APP_TITLE;
#line 3217 "AppWindow.c"
	}
#line 558 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = dialog;
#line 558 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_window_get_type (), GtkWindow), _tmp6_);
#line 559 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = dialog;
#line 559 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_dialog_get_type (), GtkDialog), affirmative, GTK_RESPONSE_YES, _ ("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
#line 562 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = dialog;
#line 562 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_dialog_get_type (), GtkDialog));
#line 564 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = dialog;
#line 564 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 566 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = (GtkResponseType) response;
#line 566 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 566 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 566 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 3243 "AppWindow.c"
}


GtkResponseType
app_window_negate_affirm_all_cancel_question (const gchar* message,
                                              const gchar* negative,
                                              const gchar* affirmative,
                                              const gchar* affirmative_all,
                                              const gchar* title,
                                              GtkWindow* parent)
{
	GtkResponseType result = 0;
	GtkWindow* _tmp0_ = NULL;
	GtkMessageDialog* dialog = NULL;
	GtkMessageDialog* _tmp3_;
	const gchar* _tmp4_ = NULL;
	GtkMessageDialog* _tmp5_;
	GtkMessageDialog* _tmp6_;
	gint response = 0;
	GtkMessageDialog* _tmp7_;
	GtkMessageDialog* _tmp8_;
#line 569 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, 0);
#line 569 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (negative != NULL, 0);
#line 569 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, 0);
#line 569 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative_all != NULL, 0);
#line 569 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), 0);
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (parent != NULL) {
#line 3277 "AppWindow.c"
		GtkWindow* _tmp1_;
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _g_object_ref0 (parent);
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp1_;
#line 3285 "AppWindow.c"
	} else {
		AppWindow* _tmp2_;
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = app_window_get_instance ();
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow);
#line 3294 "AppWindow.c"
	}
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", message);
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp3_);
#line 572 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp3_;
#line 574 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (title != NULL) {
#line 574 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = title;
#line 3306 "AppWindow.c"
	} else {
#line 574 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = RESOURCES_APP_TITLE;
#line 3310 "AppWindow.c"
	}
#line 574 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = dialog;
#line 574 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow), _tmp4_);
#line 575 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = dialog;
#line 575 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_dialog_get_type (), GtkDialog), negative, GTK_RESPONSE_NO, affirmative, GTK_RESPONSE_YES, affirmative_all, GTK_RESPONSE_APPLY, _ ("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
#line 578 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = dialog;
#line 578 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_dialog_get_type (), GtkDialog));
#line 580 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = dialog;
#line 580 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget));
#line 582 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = (GtkResponseType) response;
#line 582 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 582 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 582 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 3336 "AppWindow.c"
}


void
app_window_database_error (GError* err)
{
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
#line 586 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = err->message;
#line 586 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = g_strdup_printf (_ ("A fatal error occurred when accessing Shotwell’s library. Shotwell can" \
"not continue.\n" \
"\n" \
"%s"), _tmp0_);
#line 586 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = _tmp1_;
#line 586 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_panic (_tmp2_);
#line 586 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp2_);
#line 3356 "AppWindow.c"
}


void
app_window_panic (const gchar* msg)
{
	Application* _tmp0_;
	Application* _tmp1_;
#line 590 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (msg != NULL);
#line 591 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_critical ("AppWindow.vala:591: %s", msg);
#line 592 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_error_message (msg, NULL);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = application_get_instance ();
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	application_panic (_tmp1_);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_application_unref0 (_tmp1_);
#line 3379 "AppWindow.c"
}


static gchar*
app_window_real_get_app_role (AppWindow* self)
{
#line 597 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_critical ("Type `%s' does not implement abstract method `app_window_get_app_role'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 597 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return NULL;
#line 3390 "AppWindow.c"
}


gchar*
app_window_get_app_role (AppWindow* self)
{
#line 597 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_APP_WINDOW (self), NULL);
#line 597 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return APP_WINDOW_GET_CLASS (self)->get_app_role (self);
#line 3401 "AppWindow.c"
}


void
app_window_on_about (AppWindow* self)
{
#line 600 "/home/jens/Source/shotwell/src/AppWindow.vala"
	static const gchar* artists[2] = {"Braunschweiger Löwe created by Magnus Manske., CC BY-SA 3.0, https://c" \
"ommons.wikimedia.org/w/index.php?curid=109735", NULL};
#line 3410 "AppWindow.c"
	gchar* _tmp0_;
	gchar* _tmp1_;
	GdkPixbuf* _tmp2_;
	GdkPixbuf* _tmp3_;
#line 599 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 601 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_app_role (self);
#line 601 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 601 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = resources_get_icon (RESOURCES_ICON_ABOUT_LOGO, -1);
#line 601 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 601 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_show_about_dialog (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), "version", RESOURCES_APP_VERSION " \u2013 \"Braunschweig\"", "comments", _tmp1_, "copyright", RESOURCES_COPYRIGHT, "website", RESOURCES_HOME_URL, "license", RESOURCES_LICENSE, "website-label", _ ("Visit the Shotwell web site"), "authors", RESOURCES_AUTHORS, "logo", _tmp3_, "artists", artists, "translator-credits", _ ("translator-credits"), NULL, NULL);
#line 601 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 601 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp1_);
#line 3431 "AppWindow.c"
}


static void
app_window_on_help_contents (AppWindow* self)
{
	GError * _inner_error_ = NULL;
#line 616 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 3441 "AppWindow.c"
	{
		GdkScreen* _tmp0_;
#line 618 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 618 "/home/jens/Source/shotwell/src/AppWindow.vala"
		resources_launch_help (_tmp0_, NULL, &_inner_error_);
#line 618 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3450 "AppWindow.c"
			goto __catch240_g_error;
		}
	}
	goto __finally240;
	__catch240_g_error:
	{
		GError* err = NULL;
		GError* _tmp1_;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 617 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 617 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = err;
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = _tmp1_->message;
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = g_strdup_printf (_ ("Unable to display help: %s"), _tmp2_);
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp3_;
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp4_, NULL);
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp4_);
#line 617 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3480 "AppWindow.c"
	}
	__finally240:
#line 617 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 617 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 617 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 617 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3491 "AppWindow.c"
	}
}


static void
app_window_on_help_report_problem (AppWindow* self)
{
	GError * _inner_error_ = NULL;
#line 624 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 3502 "AppWindow.c"
	{
#line 626 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_uri (self, RESOURCES_BUG_DB_URL, &_inner_error_);
#line 626 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3508 "AppWindow.c"
			goto __catch241_g_error;
		}
	}
	goto __finally241;
	__catch241_g_error:
	{
		GError* err = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 625 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 625 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = err;
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _tmp0_->message;
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = g_strdup_printf (_ ("Unable to navigate to bug database: %s"), _tmp1_);
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp2_;
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp3_, NULL);
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp3_);
#line 625 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3538 "AppWindow.c"
	}
	__finally241:
#line 625 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 625 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 625 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 625 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3549 "AppWindow.c"
	}
}


static void
app_window_on_help_faq (AppWindow* self)
{
	GError * _inner_error_ = NULL;
#line 632 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 3560 "AppWindow.c"
	{
#line 634 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_uri (self, RESOURCES_FAQ_URL, &_inner_error_);
#line 634 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3566 "AppWindow.c"
			goto __catch242_g_error;
		}
	}
	goto __finally242;
	__catch242_g_error:
	{
		GError* err = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 633 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 633 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 636 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = err;
#line 636 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _tmp0_->message;
#line 636 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = g_strdup_printf (_ ("Unable to display FAQ: %s"), _tmp1_);
#line 636 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp2_;
#line 636 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp3_, NULL);
#line 636 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp3_);
#line 633 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3596 "AppWindow.c"
	}
	__finally242:
#line 633 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 633 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 633 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 633 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3607 "AppWindow.c"
	}
}


static void
app_window_real_on_quit (AppWindow* self)
{
	Application* _tmp0_;
	Application* _tmp1_;
#line 641 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = application_get_instance ();
#line 641 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 641 "/home/jens/Source/shotwell/src/AppWindow.vala"
	application_exit (_tmp1_);
#line 641 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_application_unref0 (_tmp1_);
#line 3625 "AppWindow.c"
}


void
app_window_on_quit (AppWindow* self)
{
#line 640 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 640 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->on_quit (self);
#line 3636 "AppWindow.c"
}


void
app_window_on_jump_to_file (AppWindow* self)
{
	Page* _tmp0_;
	Page* _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
	gboolean _tmp4_;
	MediaSource* media = NULL;
	Page* _tmp5_;
	Page* _tmp6_;
	ViewCollection* _tmp7_;
	ViewCollection* _tmp8_;
	DataView* _tmp9_;
	DataView* _tmp10_;
	DataSource* _tmp11_;
	MediaSource* _tmp12_;
	MediaSource* _tmp13_;
	MediaSource* _tmp14_;
	GError * _inner_error_ = NULL;
#line 644 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page_get_view (_tmp1_);
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = view_collection_get_selected_count (_tmp3_) != 1;
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_data_collection_unref0 (_tmp3_);
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp4_) {
#line 646 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3680 "AppWindow.c"
	}
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = _tmp5_;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = page_get_view (_tmp6_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = view_collection_get_selected_at (_tmp8_, 0);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = _tmp9_;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = data_view_get_source (_tmp10_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, TYPE_MEDIA_SOURCE) ? ((MediaSource*) _tmp11_) : NULL;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp12_ == NULL) {
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp11_);
#line 3702 "AppWindow.c"
	}
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = _tmp12_;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp10_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_data_collection_unref0 (_tmp8_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp6_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
	media = _tmp13_;
#line 650 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = media;
#line 650 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp14_ == NULL) {
#line 651 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (media);
#line 651 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3722 "AppWindow.c"
	}
	{
		AppWindow* _tmp15_;
		AppWindow* _tmp16_;
		MediaSource* _tmp17_;
		GFile* _tmp18_;
		GFile* _tmp19_;
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp15_ = app_window_get_instance ();
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp16_ = _tmp15_;
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp17_ = media;
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp18_ = media_source_get_master_file (_tmp17_);
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp19_ = _tmp18_;
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_file_uri (_tmp16_, _tmp19_, &_inner_error_);
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp19_);
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp16_);
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3748 "AppWindow.c"
			goto __catch243_g_error;
		}
	}
	goto __finally243;
	__catch243_g_error:
	{
		GError* err = NULL;
		GError* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 656 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp20_ = err;
#line 656 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp21_ = resources_jump_to_file_failed (_tmp20_);
#line 656 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp22_ = _tmp21_;
#line 656 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp22_, NULL);
#line 656 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp22_);
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3775 "AppWindow.c"
	}
	__finally243:
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (media);
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 653 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3788 "AppWindow.c"
	}
#line 644 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (media);
#line 3792 "AppWindow.c"
}


static void
app_window_real_destroy (GtkWidget* base)
{
	AppWindow * self;
#line 660 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_APP_WINDOW, AppWindow);
#line 661 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_quit (self);
#line 3804 "AppWindow.c"
}


static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 3827 "AppWindow.c"
	} else {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) old)) == '\0';
#line 3831 "AppWindow.c"
	}
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 3837 "AppWindow.c"
	} else {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
#line 3841 "AppWindow.c"
	}
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 3845 "AppWindow.c"
		gchar* _tmp2_;
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = g_strdup (self);
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = _tmp2_;
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 3853 "AppWindow.c"
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_escape_string (old, -1);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp6_ = _tmp5_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_free0 (_tmp4_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		regex = _tmp6_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3881 "AppWindow.c"
				goto __catch244_g_regex_error;
			}
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			return NULL;
#line 3890 "AppWindow.c"
		}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp8_ = regex;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp9_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3904 "AppWindow.c"
				goto __catch244_g_regex_error;
			}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			return NULL;
#line 3915 "AppWindow.c"
		}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp7_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = NULL;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = _tmp10_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_free0 (_tmp7_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 3929 "AppWindow.c"
	}
	goto __finally244;
	__catch244_g_regex_error:
	{
		GError* e = NULL;
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1429 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 3943 "AppWindow.c"
	}
	__finally244:
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return NULL;
#line 3954 "AppWindow.c"
	}
}


void
app_window_show_file_uri (AppWindow* self,
                          GFile* file,
                          GError** error)
{
	gchar* tmp = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_;
	GError * _inner_error_ = NULL;
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 669 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = get_nautilus_install_location ();
#line 669 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 669 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = _tmp1_ != NULL;
#line 669 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp1_);
#line 669 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_) {
#line 3983 "AppWindow.c"
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		const gchar* _tmp6_;
#line 670 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = g_file_get_uri (file);
#line 670 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp3_;
#line 670 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = string_replace (_tmp4_, "'", "\\\'");
#line 670 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (tmp);
#line 670 "/home/jens/Source/shotwell/src/AppWindow.vala"
		tmp = _tmp5_;
#line 670 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp4_);
#line 671 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = tmp;
#line 671 "/home/jens/Source/shotwell/src/AppWindow.vala"
		show_file_in_nautilus (_tmp6_, &_inner_error_);
#line 671 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 671 "/home/jens/Source/shotwell/src/AppWindow.vala"
			g_propagate_error (error, _inner_error_);
#line 671 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_g_free0 (tmp);
#line 671 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return;
#line 4012 "AppWindow.c"
		}
	} else {
		GFile* _tmp7_;
		GFile* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		const gchar* _tmp12_;
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = g_file_get_parent (file);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = _tmp7_;
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = g_file_get_uri (_tmp8_);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp9_;
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = string_replace (_tmp10_, "'", "\\\'");
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (tmp);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		tmp = _tmp11_;
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp10_);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp8_);
#line 674 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = tmp;
#line 674 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_uri (self, _tmp12_, &_inner_error_);
#line 674 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 674 "/home/jens/Source/shotwell/src/AppWindow.vala"
			g_propagate_error (error, _inner_error_);
#line 674 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_g_free0 (tmp);
#line 674 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return;
#line 4051 "AppWindow.c"
		}
	}
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (tmp);
#line 4056 "AppWindow.c"
}


void
app_window_show_uri (AppWindow* self,
                     const gchar* url,
                     GError** error)
{
	GdkWindow* _tmp0_;
	GdkScreen* _tmp1_;
	GError * _inner_error_ = NULL;
#line 678 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 678 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (url != NULL);
#line 679 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 679 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gdk_window_get_screen (_tmp0_);
#line 679 "/home/jens/Source/shotwell/src/AppWindow.vala"
	sys_show_uri (_tmp1_, url, &_inner_error_);
#line 679 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 679 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_propagate_error (error, _inner_error_);
#line 679 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 4084 "AppWindow.c"
	}
}


static void
app_window_real_add_actions (AppWindow* self)
{
#line 683 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_action_map_add_action_entries (G_TYPE_CHECK_INSTANCE_CAST (self, g_action_map_get_type (), GActionMap), APP_WINDOW_common_actions, G_N_ELEMENTS (APP_WINDOW_common_actions), self);
#line 4094 "AppWindow.c"
}


void
app_window_add_actions (AppWindow* self)
{
#line 682 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 682 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->add_actions (self);
#line 4105 "AppWindow.c"
}


void
app_window_go_fullscreen (AppWindow* self,
                          Page* page)
{
	FullscreenWindow* _tmp0_;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	FullscreenWindow* fsw = NULL;
	FullscreenWindow* _tmp4_;
	Page* _tmp5_;
	Page* _tmp6_;
	gboolean _tmp7_;
	FullscreenWindow* _tmp11_;
	FullscreenWindow* _tmp12_;
	FullscreenWindow* _tmp13_;
#line 686 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 686 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 688 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_fullscreen_window;
#line 688 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 4132 "AppWindow.c"
		FullscreenWindow* _tmp1_;
#line 689 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = app_window_fullscreen_window;
#line 689 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow));
#line 691 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 4140 "AppWindow.c"
	}
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_get_position (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), &_tmp2_, &_tmp3_);
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_x = _tmp2_;
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_y = _tmp3_;
#line 695 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 697 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = fullscreen_window_new (page);
#line 697 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp4_);
#line 697 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fsw = _tmp4_;
#line 699 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 699 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = _tmp5_;
#line 699 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = _tmp6_ != NULL;
#line 699 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp6_);
#line 699 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp7_) {
#line 4166 "AppWindow.c"
		Page* _tmp8_;
		Page* _tmp9_;
		FullscreenWindow* _tmp10_;
#line 700 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 700 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = _tmp8_;
#line 700 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = fsw;
#line 700 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_switching_to_fullscreen (_tmp9_, _tmp10_);
#line 700 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp9_);
#line 4180 "AppWindow.c"
	}
#line 702 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = fsw;
#line 702 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 702 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (app_window_fullscreen_window);
#line 702 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_fullscreen_window = _tmp12_;
#line 703 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = app_window_fullscreen_window;
#line 703 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_window_get_type (), GtkWindow));
#line 686 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (fsw);
#line 4196 "AppWindow.c"
}


void
app_window_end_fullscreen (AppWindow* self)
{
	FullscreenWindow* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	Page* _tmp3_;
	Page* _tmp4_;
	gboolean _tmp5_;
	FullscreenWindow* _tmp9_;
	FullscreenWindow* _tmp10_;
#line 706 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 707 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_fullscreen_window;
#line 707 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ == NULL) {
#line 708 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 4219 "AppWindow.c"
	}
#line 710 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->pos_x;
#line 710 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->pos_y;
#line 710 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_move (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp1_, _tmp2_);
#line 712 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 714 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 714 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 714 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 714 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 714 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_) {
#line 4239 "AppWindow.c"
		Page* _tmp6_;
		Page* _tmp7_;
		FullscreenWindow* _tmp8_;
#line 715 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 715 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = _tmp6_;
#line 715 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = app_window_fullscreen_window;
#line 715 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_returning_from_fullscreen (_tmp7_, _tmp8_);
#line 715 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp7_);
#line 4253 "AppWindow.c"
	}
#line 717 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = app_window_fullscreen_window;
#line 717 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 718 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = app_window_fullscreen_window;
#line 718 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 719 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (app_window_fullscreen_window);
#line 719 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_fullscreen_window = NULL;
#line 721 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 4269 "AppWindow.c"
}


GAction*
app_window_get_common_action (AppWindow* self,
                              const gchar* name)
{
	GAction* result = NULL;
	GAction* _tmp0_;
	GAction* _tmp1_;
#line 724 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_APP_WINDOW (self), NULL);
#line 724 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 725 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = g_action_map_lookup_action (G_TYPE_CHECK_INSTANCE_CAST (self, g_action_map_get_type (), GActionMap), name);
#line 725 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 725 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 725 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 4292 "AppWindow.c"
}


void
app_window_set_common_action_sensitive (AppWindow* self,
                                        const gchar* name,
                                        gboolean sensitive)
{
	GSimpleAction* action = NULL;
	GAction* _tmp0_;
	GSimpleAction* _tmp1_;
	GSimpleAction* _tmp2_;
#line 728 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 728 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_common_action (self, name);
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp0_) : NULL;
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 4317 "AppWindow.c"
	}
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp1_;
#line 730 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = action;
#line 730 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 4325 "AppWindow.c"
		GSimpleAction* _tmp3_;
#line 731 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = action;
#line 731 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp3_, sensitive);
#line 4331 "AppWindow.c"
	}
#line 728 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 4335 "AppWindow.c"
}


void
app_window_set_common_action_important (AppWindow* self,
                                        const gchar* name,
                                        gboolean important)
{
	GSimpleAction* action = NULL;
	GAction* _tmp0_;
	GSimpleAction* _tmp1_;
	GSimpleAction* _tmp2_;
#line 734 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 734 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_common_action (self, name);
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp0_) : NULL;
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 4360 "AppWindow.c"
	}
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp1_;
#line 736 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = action;
#line 736 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 4368 "AppWindow.c"
		GSimpleAction* _tmp3_;
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = action;
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp3_, _tmp5_);
#line 4380 "AppWindow.c"
	}
#line 734 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 4384 "AppWindow.c"
}


void
app_window_set_common_action_visible (AppWindow* self,
                                      const gchar* name,
                                      gboolean visible)
{
	GSimpleAction* action = NULL;
	GAction* _tmp0_;
	GSimpleAction* _tmp1_;
	GSimpleAction* _tmp2_;
#line 740 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 740 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_common_action (self, name);
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp0_) : NULL;
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 4409 "AppWindow.c"
	}
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp1_;
#line 742 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = action;
#line 742 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 4417 "AppWindow.c"
		GSimpleAction* _tmp3_;
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 743 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = action;
#line 743 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 743 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 743 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp3_, _tmp5_);
#line 4429 "AppWindow.c"
	}
#line 740 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 4433 "AppWindow.c"
}


static void
_app_window_on_update_common_actions_data_collection_contents_altered (DataCollection* _sender,
                                                                       GeeIterable* added,
                                                                       GeeIterable* removed,
                                                                       gpointer self)
{
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_update_common_actions ((AppWindow*) self);
#line 4445 "AppWindow.c"
}


static void
_app_window_on_update_common_actions_view_collection_selection_group_altered (ViewCollection* _sender,
                                                                              gpointer self)
{
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_update_common_actions ((AppWindow*) self);
#line 4455 "AppWindow.c"
}


static void
_app_window_on_update_common_actions_view_collection_items_state_changed (ViewCollection* _sender,
                                                                          GeeIterable* changed,
                                                                          gpointer self)
{
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_update_common_actions ((AppWindow*) self);
#line 4466 "AppWindow.c"
}


static void
app_window_real_switched_pages (PageWindow* base,
                                Page* old_page,
                                Page* new_page)
{
	AppWindow * self;
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_APP_WINDOW, AppWindow);
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 747 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_update_common_action_availability (self, old_page, new_page);
#line 749 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (old_page != NULL) {
#line 4486 "AppWindow.c"
		ViewCollection* _tmp0_;
		ViewCollection* _tmp1_;
		guint _tmp2_;
		ViewCollection* _tmp3_;
		ViewCollection* _tmp4_;
		guint _tmp5_;
		ViewCollection* _tmp6_;
		ViewCollection* _tmp7_;
		guint _tmp8_;
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = page_get_view (old_page);
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _tmp0_;
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp2_, NULL, FALSE);
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _app_window_on_update_common_actions_data_collection_contents_altered, self);
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp1_);
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page_get_view (old_page);
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp3_;
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_parse_name ("selection-group-altered", TYPE_VIEW_COLLECTION, &_tmp5_, NULL, FALSE);
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _app_window_on_update_common_actions_view_collection_selection_group_altered, self);
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp4_);
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = page_get_view (old_page);
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = _tmp6_;
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_parse_name ("items-state-changed", TYPE_VIEW_COLLECTION, &_tmp8_, NULL, FALSE);
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_handlers_disconnect_matched (_tmp7_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, 0, NULL, (GCallback) _app_window_on_update_common_actions_view_collection_items_state_changed, self);
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp7_);
#line 4526 "AppWindow.c"
	}
#line 755 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (new_page != NULL) {
#line 4530 "AppWindow.c"
		ViewCollection* _tmp9_;
		ViewCollection* _tmp10_;
		ViewCollection* _tmp11_;
		ViewCollection* _tmp12_;
		ViewCollection* _tmp13_;
		ViewCollection* _tmp14_;
		ViewCollection* _tmp15_;
		ViewCollection* _tmp16_;
		ViewCollection* _tmp17_;
		ViewCollection* _tmp18_;
#line 756 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = page_get_view (new_page);
#line 756 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp9_;
#line 756 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _app_window_on_update_common_actions_data_collection_contents_altered, self, 0);
#line 756 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp10_);
#line 757 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = page_get_view (new_page);
#line 757 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = _tmp11_;
#line 757 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (_tmp12_, "selection-group-altered", (GCallback) _app_window_on_update_common_actions_view_collection_selection_group_altered, self, 0);
#line 757 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp12_);
#line 758 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp13_ = page_get_view (new_page);
#line 758 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp14_ = _tmp13_;
#line 758 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (_tmp14_, "items-state-changed", (GCallback) _app_window_on_update_common_actions_view_collection_items_state_changed, self, 0);
#line 758 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp14_);
#line 760 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp15_ = page_get_view (new_page);
#line 760 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp16_ = _tmp15_;
#line 760 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp17_ = page_get_view (new_page);
#line 760 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp18_ = _tmp17_;
#line 760 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_update_common_actions (self, new_page, view_collection_get_selected_count (_tmp16_), data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, TYPE_DATA_COLLECTION, DataCollection)));
#line 760 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp18_);
#line 760 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp16_);
#line 4579 "AppWindow.c"
	}
#line 764 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_CLASS (app_window_parent_class)->switched_pages (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), old_page, new_page);
#line 4583 "AppWindow.c"
}


static void
app_window_real_update_common_action_availability (AppWindow* self,
                                                   Page* old_page,
                                                   Page* new_page)
{
	gboolean is_checkerboard = FALSE;
#line 770 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 770 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 771 "/home/jens/Source/shotwell/src/AppWindow.vala"
	is_checkerboard = G_TYPE_CHECK_INSTANCE_TYPE (new_page, TYPE_CHECKERBOARD_PAGE);
#line 773 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_set_common_action_sensitive (self, "CommonSelectAll", is_checkerboard);
#line 774 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_set_common_action_sensitive (self, "CommonSelectNone", is_checkerboard);
#line 4603 "AppWindow.c"
}


void
app_window_update_common_action_availability (AppWindow* self,
                                              Page* old_page,
                                              Page* new_page)
{
#line 770 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 770 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->update_common_action_availability (self, old_page, new_page);
#line 4616 "AppWindow.c"
}


static void
app_window_real_update_common_actions (AppWindow* self,
                                       Page* page,
                                       gint selected_count,
                                       gint count)
{
#line 780 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 781 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (page, TYPE_CHECKERBOARD_PAGE)) {
#line 782 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_set_common_action_sensitive (self, "CommonSelectAll", count > 0);
#line 4632 "AppWindow.c"
	}
#line 783 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_set_common_action_sensitive (self, "CommonJumpToFile", selected_count == 1);
#line 785 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_undo_action (self);
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_redo_action (self);
#line 4640 "AppWindow.c"
}


void
app_window_update_common_actions (AppWindow* self,
                                  Page* page,
                                  gint selected_count,
                                  gint count)
{
#line 780 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 780 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->update_common_actions (self, page, selected_count, count);
#line 4654 "AppWindow.c"
}


static void
app_window_on_update_common_actions (AppWindow* self)
{
	Page* page = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
#line 789 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 790 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 790 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = _tmp0_;
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = page;
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 4674 "AppWindow.c"
		Page* _tmp2_;
		Page* _tmp3_;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
		Page* _tmp6_;
		ViewCollection* _tmp7_;
		ViewCollection* _tmp8_;
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = page;
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = page;
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = page_get_view (_tmp6_);
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = _tmp7_;
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_update_common_actions (self, _tmp2_, view_collection_get_selected_count (_tmp5_), data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_DATA_COLLECTION, DataCollection)));
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp8_);
#line 792 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 4702 "AppWindow.c"
	}
#line 789 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 4706 "AppWindow.c"
}


void
app_window_update_menu_item_label (AppWindow* self,
                                   const gchar* id,
                                   const gchar* new_label)
{
	GMenu* bar = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
	GMenuModel* _tmp2_;
	GMenu* _tmp3_;
	GMenu* _tmp4_;
	GMenu* _tmp5_;
	gint items = 0;
	GMenu* _tmp6_;
#line 795 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 795 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (id != NULL);
#line 795 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (new_label != NULL);
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page_get_menubar (_tmp1_);
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, g_menu_get_type ()) ? ((GMenu*) _tmp2_) : NULL;
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ == NULL) {
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp2_);
#line 4742 "AppWindow.c"
	}
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	bar = _tmp4_;
#line 799 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = bar;
#line 799 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_ == NULL) {
#line 800 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (bar);
#line 800 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 4758 "AppWindow.c"
	}
#line 803 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = bar;
#line 803 "/home/jens/Source/shotwell/src/AppWindow.vala"
	items = g_menu_model_get_n_items (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, g_menu_model_get_type (), GMenuModel));
#line 4764 "AppWindow.c"
	{
		gint i = 0;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
		i = 0;
#line 4769 "AppWindow.c"
		{
			gboolean _tmp7_ = FALSE;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_tmp7_ = TRUE;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
			while (TRUE) {
#line 4776 "AppWindow.c"
				gint _tmp9_;
				gint _tmp10_;
				GMenuModel* model = NULL;
				GMenu* _tmp11_;
				gint _tmp12_;
				GMenuModel* _tmp13_;
				GMenu* _tmp14_;
				gint model_items = 0;
				GMenuModel* _tmp15_;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				if (!_tmp7_) {
#line 4788 "AppWindow.c"
					gint _tmp8_;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
					_tmp8_ = i;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
					i = _tmp8_ + 1;
#line 4794 "AppWindow.c"
				}
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp7_ = FALSE;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp9_ = i;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp10_ = items;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				if (!(_tmp9_ < _tmp10_)) {
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
					break;
#line 4806 "AppWindow.c"
				}
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp11_ = bar;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp12_ = i;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp13_ = g_menu_model_get_item_link (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, g_menu_model_get_type (), GMenuModel), _tmp12_, G_MENU_LINK_SUBMENU);
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
				model = _tmp13_;
#line 806 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp14_ = bar;
#line 806 "/home/jens/Source/shotwell/src/AppWindow.vala"
				if (_tmp14_ == NULL) {
#line 807 "/home/jens/Source/shotwell/src/AppWindow.vala"
					_g_object_unref0 (model);
#line 807 "/home/jens/Source/shotwell/src/AppWindow.vala"
					continue;
#line 4824 "AppWindow.c"
				}
#line 810 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp15_ = model;
#line 810 "/home/jens/Source/shotwell/src/AppWindow.vala"
				model_items = g_menu_model_get_n_items (_tmp15_);
#line 4830 "AppWindow.c"
				{
					gint j = 0;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
					j = 0;
#line 4835 "AppWindow.c"
					{
						gboolean _tmp16_ = FALSE;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
						_tmp16_ = TRUE;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
						while (TRUE) {
#line 4842 "AppWindow.c"
							gint _tmp18_;
							gint _tmp19_;
							GMenuModel* subsection = NULL;
							GMenuModel* _tmp20_;
							gint _tmp21_;
							GMenuModel* _tmp22_;
							GMenuModel* _tmp23_;
							gint sub_items = 0;
							GMenuModel* _tmp24_;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
							if (!_tmp16_) {
#line 4854 "AppWindow.c"
								gint _tmp17_;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
								_tmp17_ = j;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
								j = _tmp17_ + 1;
#line 4860 "AppWindow.c"
							}
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp16_ = FALSE;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp18_ = j;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp19_ = model_items;
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
							if (!(_tmp18_ < _tmp19_)) {
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
								break;
#line 4872 "AppWindow.c"
							}
#line 812 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp20_ = model;
#line 812 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp21_ = j;
#line 812 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp22_ = g_menu_model_get_item_link (_tmp20_, _tmp21_, G_MENU_LINK_SECTION);
#line 812 "/home/jens/Source/shotwell/src/AppWindow.vala"
							subsection = _tmp22_;
#line 814 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp23_ = subsection;
#line 814 "/home/jens/Source/shotwell/src/AppWindow.vala"
							if (_tmp23_ == NULL) {
#line 815 "/home/jens/Source/shotwell/src/AppWindow.vala"
								_g_object_unref0 (subsection);
#line 815 "/home/jens/Source/shotwell/src/AppWindow.vala"
								continue;
#line 4890 "AppWindow.c"
							}
#line 818 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp24_ = subsection;
#line 818 "/home/jens/Source/shotwell/src/AppWindow.vala"
							sub_items = g_menu_model_get_n_items (_tmp24_);
#line 4896 "AppWindow.c"
							{
								gint k = 0;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
								k = 0;
#line 4901 "AppWindow.c"
								{
									gboolean _tmp25_ = FALSE;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
									_tmp25_ = TRUE;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
									while (TRUE) {
#line 4908 "AppWindow.c"
										gint _tmp27_;
										gint _tmp28_;
										GMenuAttributeIter* it = NULL;
										GMenuModel* _tmp29_;
										gint _tmp30_;
										GMenuAttributeIter* _tmp31_;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
										if (!_tmp25_) {
#line 4917 "AppWindow.c"
											gint _tmp26_;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp26_ = k;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
											k = _tmp26_ + 1;
#line 4923 "AppWindow.c"
										}
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp25_ = FALSE;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp27_ = k;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp28_ = sub_items;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
										if (!(_tmp27_ < _tmp28_)) {
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
											break;
#line 4935 "AppWindow.c"
										}
#line 820 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp29_ = subsection;
#line 820 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp30_ = k;
#line 820 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp31_ = g_menu_model_iterate_item_attributes (_tmp29_, _tmp30_);
#line 820 "/home/jens/Source/shotwell/src/AppWindow.vala"
										it = _tmp31_;
#line 821 "/home/jens/Source/shotwell/src/AppWindow.vala"
										while (TRUE) {
#line 4947 "AppWindow.c"
											GMenuAttributeIter* _tmp32_;
											gboolean _tmp33_ = FALSE;
											gboolean _tmp34_ = FALSE;
											GMenuAttributeIter* _tmp35_;
											const gchar* _tmp36_;
#line 821 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp32_ = it;
#line 821 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (!g_menu_attribute_iter_next (_tmp32_)) {
#line 821 "/home/jens/Source/shotwell/src/AppWindow.vala"
												break;
#line 4959 "AppWindow.c"
											}
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp35_ = it;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp36_ = g_menu_attribute_iter_get_name (_tmp35_);
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (g_strcmp0 (_tmp36_, "id") == 0) {
#line 4967 "AppWindow.c"
												GMenuAttributeIter* _tmp37_;
												GVariant* _tmp38_;
												GVariant* _tmp39_;
												const gchar* _tmp40_;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp37_ = it;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp38_ = g_menu_attribute_iter_get_value (_tmp37_);
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp39_ = _tmp38_;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp40_ = g_variant_get_string (_tmp39_, NULL);
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp34_ = g_strcmp0 (_tmp40_, id) == 0;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_variant_unref0 (_tmp39_);
#line 4984 "AppWindow.c"
											} else {
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp34_ = FALSE;
#line 4988 "AppWindow.c"
											}
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (_tmp34_) {
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp33_ = TRUE;
#line 4994 "AppWindow.c"
											} else {
												gboolean _tmp41_ = FALSE;
												GMenuAttributeIter* _tmp42_;
												const gchar* _tmp43_;
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp42_ = it;
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp43_ = g_menu_attribute_iter_get_name (_tmp42_);
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
												if (g_strcmp0 (_tmp43_, "action") == 0) {
#line 5005 "AppWindow.c"
													GMenuAttributeIter* _tmp44_;
													GVariant* _tmp45_;
													GVariant* _tmp46_;
													const gchar* _tmp47_;
													gchar* _tmp48_;
													gchar* _tmp49_;
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp44_ = it;
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp45_ = g_menu_attribute_iter_get_value (_tmp44_);
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp46_ = _tmp45_;
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp47_ = g_variant_get_string (_tmp46_, NULL);
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp48_ = g_strconcat (".", id, NULL);
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp49_ = _tmp48_;
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp41_ = g_str_has_suffix (_tmp47_, _tmp49_);
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_g_free0 (_tmp49_);
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_g_variant_unref0 (_tmp46_);
#line 5030 "AppWindow.c"
												} else {
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp41_ = FALSE;
#line 5034 "AppWindow.c"
												}
#line 823 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp33_ = _tmp41_;
#line 5038 "AppWindow.c"
											}
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (_tmp33_) {
#line 5042 "AppWindow.c"
												GMenu* md = NULL;
												GMenuModel* _tmp50_;
												GMenu* _tmp51_;
												GMenuItem* m = NULL;
												GMenuModel* _tmp52_;
												gint _tmp53_;
												GMenuItem* _tmp54_;
												GMenuItem* _tmp55_;
												GMenu* _tmp56_;
												gint _tmp57_;
												GMenu* _tmp58_;
												gint _tmp59_;
												GMenuItem* _tmp60_;
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp50_ = subsection;
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp51_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, g_menu_get_type ()) ? ((GMenu*) _tmp50_) : NULL);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												md = _tmp51_;
#line 825 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp52_ = subsection;
#line 825 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp53_ = k;
#line 825 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp54_ = g_menu_item_new_from_model (_tmp52_, _tmp53_);
#line 825 "/home/jens/Source/shotwell/src/AppWindow.vala"
												m = _tmp54_;
#line 826 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp55_ = m;
#line 826 "/home/jens/Source/shotwell/src/AppWindow.vala"
												g_menu_item_set_label (_tmp55_, new_label);
#line 827 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp56_ = md;
#line 827 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp57_ = k;
#line 827 "/home/jens/Source/shotwell/src/AppWindow.vala"
												g_menu_remove (_tmp56_, _tmp57_);
#line 828 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp58_ = md;
#line 828 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp59_ = k;
#line 828 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp60_ = m;
#line 828 "/home/jens/Source/shotwell/src/AppWindow.vala"
												g_menu_insert_item (_tmp58_, _tmp59_, _tmp60_);
#line 830 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (m);
#line 830 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (md);
#line 830 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (it);
#line 830 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (subsection);
#line 830 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (model);
#line 830 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (bar);
#line 830 "/home/jens/Source/shotwell/src/AppWindow.vala"
												return;
#line 5102 "AppWindow.c"
											}
										}
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_g_object_unref0 (it);
#line 5107 "AppWindow.c"
									}
								}
							}
#line 811 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_g_object_unref0 (subsection);
#line 5113 "AppWindow.c"
						}
					}
				}
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_g_object_unref0 (model);
#line 5119 "AppWindow.c"
			}
		}
	}
#line 795 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (bar);
#line 5125 "AppWindow.c"
}


static gpointer
_command_manager_ref0 (gpointer self)
{
#line 841 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self ? command_manager_ref (self) : NULL;
#line 5134 "AppWindow.c"
}


CommandManager*
app_window_get_command_manager (void)
{
	CommandManager* result = NULL;
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
#line 841 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_command_manager;
#line 841 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _command_manager_ref0 (_tmp0_);
#line 841 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 841 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 5152 "AppWindow.c"
}


static void
app_window_on_command_manager_altered (AppWindow* self)
{
#line 844 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 845 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_undo_action (self);
#line 846 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_redo_action (self);
#line 5165 "AppWindow.c"
}


static void
app_window_decorate_command_manager_action (AppWindow* self,
                                            const gchar* name,
                                            const gchar* prefix,
                                            const gchar* default_explanation,
                                            CommandDescription* desc)
{
	GSimpleAction* action = NULL;
	GAction* _tmp0_;
	GSimpleAction* _tmp1_;
	GSimpleAction* _tmp2_;
	gchar* label = NULL;
	gchar* _tmp3_;
	const gchar* _tmp13_;
#line 849 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 849 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 849 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (prefix != NULL);
#line 849 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (default_explanation != NULL);
#line 849 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((desc == NULL) || IS_COMMAND_DESCRIPTION (desc));
#line 851 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_common_action (self, name);
#line 851 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp0_) : NULL;
#line 851 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 851 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 5201 "AppWindow.c"
	}
#line 851 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp1_;
#line 852 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = action;
#line 852 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ == NULL) {
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (action);
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 5213 "AppWindow.c"
	}
#line 856 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = g_strdup (prefix);
#line 856 "/home/jens/Source/shotwell/src/AppWindow.vala"
	label = _tmp3_;
#line 858 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (desc != NULL) {
#line 5221 "AppWindow.c"
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GSimpleAction* _tmp10_;
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = label;
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = command_description_get_name (desc);
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = _tmp5_;
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = g_strconcat (" ", _tmp6_, NULL);
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = _tmp7_;
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = g_strconcat (_tmp4_, _tmp8_, NULL);
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (label);
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		label = _tmp9_;
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp8_);
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp6_);
#line 860 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = action;
#line 860 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp10_, TRUE);
#line 5253 "AppWindow.c"
	} else {
		gchar* _tmp11_;
		GSimpleAction* _tmp12_;
#line 862 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = g_strdup (prefix);
#line 862 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (label);
#line 862 "/home/jens/Source/shotwell/src/AppWindow.vala"
		label = _tmp11_;
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = action;
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp12_, FALSE);
#line 5267 "AppWindow.c"
	}
#line 865 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = label;
#line 865 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_update_menu_item_label (self, name, _tmp13_);
#line 849 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (label);
#line 849 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 5277 "AppWindow.c"
}


void
app_window_decorate_undo_action (AppWindow* self)
{
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
	CommandDescription* _tmp2_;
	CommandDescription* _tmp3_;
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 869 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_command_manager ();
#line 869 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 869 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = command_manager_get_undo_description (_tmp1_);
#line 869 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 869 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_command_manager_action (self, "CommonUndo", RESOURCES_UNDO_MENU, "", _tmp3_);
#line 869 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 869 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_command_manager_unref0 (_tmp1_);
#line 5304 "AppWindow.c"
}


void
app_window_decorate_redo_action (AppWindow* self)
{
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
	CommandDescription* _tmp2_;
	CommandDescription* _tmp3_;
#line 873 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 874 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_command_manager ();
#line 874 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 874 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = command_manager_get_redo_description (_tmp1_);
#line 874 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 874 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_command_manager_action (self, "CommonRedo", RESOURCES_REDO_MENU, "", _tmp3_);
#line 874 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 874 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_command_manager_unref0 (_tmp1_);
#line 5331 "AppWindow.c"
}


static void
app_window_on_undo (AppWindow* self)
{
	CommandManager* _tmp0_;
#line 878 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 879 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_command_manager;
#line 879 "/home/jens/Source/shotwell/src/AppWindow.vala"
	command_manager_undo (_tmp0_);
#line 5345 "AppWindow.c"
}


static void
app_window_on_redo (AppWindow* self)
{
	CommandManager* _tmp0_;
#line 882 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 883 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_command_manager;
#line 883 "/home/jens/Source/shotwell/src/AppWindow.vala"
	command_manager_redo (_tmp0_);
#line 5359 "AppWindow.c"
}


static void
app_window_on_select_all (AppWindow* self)
{
	Page* page = NULL;
	Page* _tmp0_;
	CheckerboardPage* _tmp1_;
	Page* _tmp2_;
#line 886 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_CHECKERBOARD_PAGE) ? ((CheckerboardPage*) _tmp0_) : NULL;
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 5380 "AppWindow.c"
	}
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PAGE, Page);
#line 888 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page;
#line 888 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 5388 "AppWindow.c"
		Page* _tmp3_;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		view_collection_select_all (_tmp5_);
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 5402 "AppWindow.c"
	}
#line 886 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 5406 "AppWindow.c"
}


static void
app_window_on_select_none (AppWindow* self)
{
	Page* page = NULL;
	Page* _tmp0_;
	CheckerboardPage* _tmp1_;
	Page* _tmp2_;
#line 892 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_CHECKERBOARD_PAGE) ? ((CheckerboardPage*) _tmp0_) : NULL;
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 5427 "AppWindow.c"
	}
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PAGE, Page);
#line 894 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page;
#line 894 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 5435 "AppWindow.c"
		Page* _tmp3_;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
#line 895 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 895 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 895 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 895 "/home/jens/Source/shotwell/src/AppWindow.vala"
		view_collection_unselect_all (_tmp5_);
#line 895 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 5449 "AppWindow.c"
	}
#line 892 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 5453 "AppWindow.c"
}


static gboolean
app_window_real_configure_event (GtkWidget* base,
                                 GdkEventConfigure* event)
{
	AppWindow * self;
	gboolean result = FALSE;
	GdkWindow* _tmp0_;
	gboolean _tmp1_;
#line 898 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_APP_WINDOW, AppWindow);
#line 898 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 899 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 899 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->maximized = gdk_window_get_state (_tmp0_) == GDK_WINDOW_STATE_MAXIMIZED;
#line 901 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->maximized;
#line 901 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp1_) {
#line 5477 "AppWindow.c"
		gint _tmp2_ = 0;
		gint _tmp3_ = 0;
#line 902 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_window_get_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), &_tmp2_, &_tmp3_);
#line 902 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions.width = _tmp2_;
#line 902 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions.height = _tmp3_;
#line 5486 "AppWindow.c"
	}
#line 904 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = GTK_WIDGET_CLASS (app_window_parent_class)->configure_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), event);
#line 904 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 5492 "AppWindow.c"
}


static void
app_window_class_init (AppWindowClass * klass)
{
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_parent_class = g_type_class_peek_parent (klass);
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->on_fullscreen = (void (*) (AppWindow *)) app_window_real_on_fullscreen;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->get_app_role = (gchar* (*) (AppWindow *)) app_window_real_get_app_role;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->on_quit = (void (*) (AppWindow *)) app_window_real_on_quit;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->destroy = (void (*) (GtkWidget *)) app_window_real_destroy;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->add_actions = (void (*) (AppWindow *)) app_window_real_add_actions;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->switched_pages = (void (*) (PageWindow *, Page*, Page*)) app_window_real_switched_pages;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->update_common_action_availability = (void (*) (AppWindow *, Page*, Page*)) app_window_real_update_common_action_availability;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->update_common_actions = (void (*) (AppWindow *, Page*, gint, gint)) app_window_real_update_common_actions;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->configure_event = (gboolean (*) (GtkWidget *, GdkEventConfigure*)) app_window_real_configure_event;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = app_window_finalize;
#line 5521 "AppWindow.c"
}


static void
app_window_instance_init (AppWindow * self)
{
#line 409 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->maximized = FALSE;
#line 411 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_x = 0;
#line 412 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_y = 0;
#line 5534 "AppWindow.c"
}


static void
app_window_finalize (GObject * obj)
{
	AppWindow * self;
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_APP_WINDOW, AppWindow);
#line 399 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (app_window_parent_class)->finalize (obj);
#line 5546 "AppWindow.c"
}


GType
app_window_get_type (void)
{
	static volatile gsize app_window_type_id__volatile = 0;
	if (g_once_init_enter (&app_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AppWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) app_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AppWindow), 0, (GInstanceInitFunc) app_window_instance_init, NULL };
		GType app_window_type_id;
		app_window_type_id = g_type_register_static (TYPE_PAGE_WINDOW, "AppWindow", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&app_window_type_id__volatile, app_window_type_id);
	}
	return app_window_type_id__volatile;
}



